agreement_with_namespace

package
v0.88.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 28, 2026 License: MIT Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client for agreement with namespace API

func (*Client) DownloadExportedAgreementsInCSV deprecated added in v0.68.0

Deprecated: 2022-08-10 - Use DownloadExportedAgreementsInCSVShort instead.

DownloadExportedAgreementsInCSV download exported users accepted agreements in csv This API will check the status of export process. If the export process has been completed, the response body will include the download url.

func (*Client) DownloadExportedAgreementsInCSVShort added in v0.68.0

func (a *Client) DownloadExportedAgreementsInCSVShort(params *DownloadExportedAgreementsInCSVParams, authInfo runtime.ClientAuthInfoWriter) (*DownloadExportedAgreementsInCSVOK, error)

DownloadExportedAgreementsInCSVShort download exported users accepted agreements in csv This API will check the status of export process. If the export process has been completed, the response body will include the download url.

func (*Client) InitiateExportAgreementsToCSV deprecated added in v0.68.0

Deprecated: 2022-08-10 - Use InitiateExportAgreementsToCSVShort instead.

InitiateExportAgreementsToCSV initiate export users accepted agreements to csv This API will initiate a worker to export list of users who has accepted a specific policy version into a CSV file. To check the export state after initialize it, use `GET /admin/namespaces/{namespace}/agreements/policy-versions/users/export-csv/download` API.

This Initiate API is not allow multiple export worker running for the same namespace, it will return 409 http error if so.

func (*Client) InitiateExportAgreementsToCSVShort added in v0.68.0

func (a *Client) InitiateExportAgreementsToCSVShort(params *InitiateExportAgreementsToCSVParams, authInfo runtime.ClientAuthInfoWriter) (*InitiateExportAgreementsToCSVOK, error)

InitiateExportAgreementsToCSVShort initiate export users accepted agreements to csv This API will initiate a worker to export list of users who has accepted a specific policy version into a CSV file. To check the export state after initialize it, use `GET /admin/namespaces/{namespace}/agreements/policy-versions/users/export-csv/download` API.

This Initiate API is not allow multiple export worker running for the same namespace, it will return 409 http error if so.

func (*Client) RetrieveAcceptedAgreements deprecated added in v0.84.0

func (a *Client) RetrieveAcceptedAgreements(params *RetrieveAcceptedAgreementsParams, authInfo runtime.ClientAuthInfoWriter) (*RetrieveAcceptedAgreementsOK, error)

Deprecated: 2022-08-10 - Use RetrieveAcceptedAgreementsShort instead.

RetrieveAcceptedAgreements retrieve accepted legal agreements This API will return all accepted Legal Agreements for specified user.

func (*Client) RetrieveAcceptedAgreementsForMultiUsers deprecated added in v0.40.0

Deprecated: 2022-08-10 - Use RetrieveAcceptedAgreementsForMultiUsersShort instead.

RetrieveAcceptedAgreementsForMultiUsers retrieve accepted legal agreements for multi users This API will return all accepted Legal Agreements for each user, including agreements of game users if publisher user has corresponding game account.

func (*Client) RetrieveAcceptedAgreementsForMultiUsersShort added in v0.40.0

func (a *Client) RetrieveAcceptedAgreementsForMultiUsersShort(params *RetrieveAcceptedAgreementsForMultiUsersParams, authInfo runtime.ClientAuthInfoWriter) (*RetrieveAcceptedAgreementsForMultiUsersOK, error)

RetrieveAcceptedAgreementsForMultiUsersShort retrieve accepted legal agreements for multi users This API will return all accepted Legal Agreements for each user, including agreements of game users if publisher user has corresponding game account.

func (*Client) RetrieveAcceptedAgreementsShort added in v0.84.0

func (a *Client) RetrieveAcceptedAgreementsShort(params *RetrieveAcceptedAgreementsParams, authInfo runtime.ClientAuthInfoWriter) (*RetrieveAcceptedAgreementsOK, error)

RetrieveAcceptedAgreementsShort retrieve accepted legal agreements This API will return all accepted Legal Agreements for specified user.

func (*Client) RetrieveAllUsersByPolicyVersion deprecated added in v0.84.0

Deprecated: 2022-08-10 - Use RetrieveAllUsersByPolicyVersionShort instead.

RetrieveAllUsersByPolicyVersion retrieve users accepting legal agreements This API will return all users who has accepted a specific policy version.

func (*Client) RetrieveAllUsersByPolicyVersionShort added in v0.84.0

func (a *Client) RetrieveAllUsersByPolicyVersionShort(params *RetrieveAllUsersByPolicyVersionParams, authInfo runtime.ClientAuthInfoWriter) (*RetrieveAllUsersByPolicyVersionOK, error)

RetrieveAllUsersByPolicyVersionShort retrieve users accepting legal agreements This API will return all users who has accepted a specific policy version.

func (*Client) SetTransport

func (a *Client) SetTransport(transport runtime.ClientTransport)

SetTransport changes the transport on the client

type ClientService

type ClientService interface {
	RetrieveAcceptedAgreementsForMultiUsers(params *RetrieveAcceptedAgreementsForMultiUsersParams, authInfo runtime.ClientAuthInfoWriter) (*RetrieveAcceptedAgreementsForMultiUsersOK, error)
	RetrieveAcceptedAgreementsForMultiUsersShort(params *RetrieveAcceptedAgreementsForMultiUsersParams, authInfo runtime.ClientAuthInfoWriter) (*RetrieveAcceptedAgreementsForMultiUsersOK, error)
	RetrieveAcceptedAgreements(params *RetrieveAcceptedAgreementsParams, authInfo runtime.ClientAuthInfoWriter) (*RetrieveAcceptedAgreementsOK, error)
	RetrieveAcceptedAgreementsShort(params *RetrieveAcceptedAgreementsParams, authInfo runtime.ClientAuthInfoWriter) (*RetrieveAcceptedAgreementsOK, error)
	RetrieveAllUsersByPolicyVersion(params *RetrieveAllUsersByPolicyVersionParams, authInfo runtime.ClientAuthInfoWriter) (*RetrieveAllUsersByPolicyVersionOK, *RetrieveAllUsersByPolicyVersionNotFound, error)
	RetrieveAllUsersByPolicyVersionShort(params *RetrieveAllUsersByPolicyVersionParams, authInfo runtime.ClientAuthInfoWriter) (*RetrieveAllUsersByPolicyVersionOK, error)
	DownloadExportedAgreementsInCSV(params *DownloadExportedAgreementsInCSVParams, authInfo runtime.ClientAuthInfoWriter) (*DownloadExportedAgreementsInCSVOK, *DownloadExportedAgreementsInCSVNotFound, error)
	DownloadExportedAgreementsInCSVShort(params *DownloadExportedAgreementsInCSVParams, authInfo runtime.ClientAuthInfoWriter) (*DownloadExportedAgreementsInCSVOK, error)
	InitiateExportAgreementsToCSV(params *InitiateExportAgreementsToCSVParams, authInfo runtime.ClientAuthInfoWriter) (*InitiateExportAgreementsToCSVOK, *InitiateExportAgreementsToCSVBadRequest, *InitiateExportAgreementsToCSVNotFound, *InitiateExportAgreementsToCSVConflict, error)
	InitiateExportAgreementsToCSVShort(params *InitiateExportAgreementsToCSVParams, authInfo runtime.ClientAuthInfoWriter) (*InitiateExportAgreementsToCSVOK, error)

	SetTransport(transport runtime.ClientTransport)
}

ClientService is the interface for Client methods

func New

func New(transport runtime.ClientTransport, formats strfmt.Registry) ClientService

New creates a new agreement with namespace API client.

type DownloadExportedAgreementsInCSVNotFound added in v0.68.0

type DownloadExportedAgreementsInCSVNotFound struct {
	Payload *legalclientmodels.ErrorEntity
}

DownloadExportedAgreementsInCSVNotFound handles this case with default header values.

<table><tr><td>NumericErrorCode</td><td>ErrorCode</td></tr><tr><td>40047</td><td>Exported agreements for exportId [{exportId}] not found</td></tr></table>

func NewDownloadExportedAgreementsInCSVNotFound added in v0.68.0

func NewDownloadExportedAgreementsInCSVNotFound() *DownloadExportedAgreementsInCSVNotFound

NewDownloadExportedAgreementsInCSVNotFound creates a DownloadExportedAgreementsInCSVNotFound with default headers values

func (*DownloadExportedAgreementsInCSVNotFound) Error added in v0.68.0

func (*DownloadExportedAgreementsInCSVNotFound) GetPayload added in v0.68.0

func (*DownloadExportedAgreementsInCSVNotFound) ToJSONString added in v0.68.0

type DownloadExportedAgreementsInCSVOK added in v0.68.0

type DownloadExportedAgreementsInCSVOK struct {
	Payload *legalclientmodels.DownloadExportedAgreementsInCSVResponse
}

DownloadExportedAgreementsInCSVOK handles this case with default header values.

successful operation

func NewDownloadExportedAgreementsInCSVOK added in v0.68.0

func NewDownloadExportedAgreementsInCSVOK() *DownloadExportedAgreementsInCSVOK

NewDownloadExportedAgreementsInCSVOK creates a DownloadExportedAgreementsInCSVOK with default headers values

func (*DownloadExportedAgreementsInCSVOK) Error added in v0.68.0

func (*DownloadExportedAgreementsInCSVOK) GetPayload added in v0.68.0

func (*DownloadExportedAgreementsInCSVOK) ToJSONString added in v0.68.0

func (o *DownloadExportedAgreementsInCSVOK) ToJSONString() string

type DownloadExportedAgreementsInCSVParams added in v0.68.0

type DownloadExportedAgreementsInCSVParams struct {

	/*RetryPolicy*/
	RetryPolicy *utils.Retry
	/*Namespace
	  Namespace

	*/
	Namespace string
	/*ExportID
	  Export Id

	*/
	ExportID string

	AuthInfoWriter runtime.ClientAuthInfoWriter
	Context        context.Context
	HTTPClient     *http.Client

	// XFlightId is an optional parameter from this SDK
	XFlightId *string
	// contains filtered or unexported fields
}

DownloadExportedAgreementsInCSVParams contains all the parameters to send to the API endpoint for the download exported agreements in csv operation typically these are written to a http.Request

func NewDownloadExportedAgreementsInCSVParams added in v0.68.0

func NewDownloadExportedAgreementsInCSVParams() *DownloadExportedAgreementsInCSVParams

NewDownloadExportedAgreementsInCSVParams creates a new DownloadExportedAgreementsInCSVParams object with the default values initialized.

func NewDownloadExportedAgreementsInCSVParamsWithContext added in v0.68.0

func NewDownloadExportedAgreementsInCSVParamsWithContext(ctx context.Context) *DownloadExportedAgreementsInCSVParams

NewDownloadExportedAgreementsInCSVParamsWithContext creates a new DownloadExportedAgreementsInCSVParams object with the default values initialized, and the ability to set a context for a request

func NewDownloadExportedAgreementsInCSVParamsWithHTTPClient added in v0.68.0

func NewDownloadExportedAgreementsInCSVParamsWithHTTPClient(client *http.Client) *DownloadExportedAgreementsInCSVParams

NewDownloadExportedAgreementsInCSVParamsWithHTTPClient creates a new DownloadExportedAgreementsInCSVParams object with the default values initialized, and the ability to set a custom HTTPClient for a request

func NewDownloadExportedAgreementsInCSVParamsWithTimeout added in v0.68.0

func NewDownloadExportedAgreementsInCSVParamsWithTimeout(timeout time.Duration) *DownloadExportedAgreementsInCSVParams

NewDownloadExportedAgreementsInCSVParamsWithTimeout creates a new DownloadExportedAgreementsInCSVParams object with the default values initialized, and the ability to set a timeout on a request

func (*DownloadExportedAgreementsInCSVParams) SetAuthInfoWriter added in v0.68.0

func (o *DownloadExportedAgreementsInCSVParams) SetAuthInfoWriter(authInfoWriter runtime.ClientAuthInfoWriter)

SetAuthInfoWriter adds the authInfoWriter to the download exported agreements in csv params

func (*DownloadExportedAgreementsInCSVParams) SetContext added in v0.68.0

SetContext adds the context to the download exported agreements in csv params

func (*DownloadExportedAgreementsInCSVParams) SetExportID added in v0.69.0

func (o *DownloadExportedAgreementsInCSVParams) SetExportID(exportID string)

SetExportID adds the exportId to the download exported agreements in csv params

func (*DownloadExportedAgreementsInCSVParams) SetFlightId added in v0.68.0

func (o *DownloadExportedAgreementsInCSVParams) SetFlightId(flightId string)

SetFlightId adds the flightId as the header value for this specific endpoint

func (*DownloadExportedAgreementsInCSVParams) SetHTTPClient added in v0.68.0

func (o *DownloadExportedAgreementsInCSVParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the download exported agreements in csv params

func (*DownloadExportedAgreementsInCSVParams) SetHTTPClientTransport added in v0.68.0

func (o *DownloadExportedAgreementsInCSVParams) SetHTTPClientTransport(roundTripper http.RoundTripper)

SetHTTPClient adds the HTTPClient Transport to the download exported agreements in csv params

func (*DownloadExportedAgreementsInCSVParams) SetNamespace added in v0.68.0

func (o *DownloadExportedAgreementsInCSVParams) SetNamespace(namespace string)

SetNamespace adds the namespace to the download exported agreements in csv params

func (*DownloadExportedAgreementsInCSVParams) SetTimeout added in v0.68.0

func (o *DownloadExportedAgreementsInCSVParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the download exported agreements in csv params

func (*DownloadExportedAgreementsInCSVParams) WithContext added in v0.68.0

WithContext adds the context to the download exported agreements in csv params

func (*DownloadExportedAgreementsInCSVParams) WithExportID added in v0.69.0

WithExportID adds the exportID to the download exported agreements in csv params

func (*DownloadExportedAgreementsInCSVParams) WithHTTPClient added in v0.68.0

WithHTTPClient adds the HTTPClient to the download exported agreements in csv params

func (*DownloadExportedAgreementsInCSVParams) WithNamespace added in v0.68.0

WithNamespace adds the namespace to the download exported agreements in csv params

func (*DownloadExportedAgreementsInCSVParams) WithTimeout added in v0.68.0

WithTimeout adds the timeout to the download exported agreements in csv params

func (*DownloadExportedAgreementsInCSVParams) WriteToRequest added in v0.68.0

WriteToRequest writes these params to a swagger request

type DownloadExportedAgreementsInCSVReader added in v0.68.0

type DownloadExportedAgreementsInCSVReader struct {
	// contains filtered or unexported fields
}

DownloadExportedAgreementsInCSVReader is a Reader for the DownloadExportedAgreementsInCSV structure.

func (*DownloadExportedAgreementsInCSVReader) ReadResponse added in v0.68.0

func (o *DownloadExportedAgreementsInCSVReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type InitiateExportAgreementsToCSVBadRequest added in v0.69.0

type InitiateExportAgreementsToCSVBadRequest struct {
	Payload *legalclientmodels.ErrorEntity
}

InitiateExportAgreementsToCSVBadRequest handles this case with default header values.

<table><tr><td>NumericErrorCode</td><td>ErrorCode</td></tr><tr><td>40027</td><td>Too many export running currently</td></tr></table>

func NewInitiateExportAgreementsToCSVBadRequest added in v0.69.0

func NewInitiateExportAgreementsToCSVBadRequest() *InitiateExportAgreementsToCSVBadRequest

NewInitiateExportAgreementsToCSVBadRequest creates a InitiateExportAgreementsToCSVBadRequest with default headers values

func (*InitiateExportAgreementsToCSVBadRequest) Error added in v0.69.0

func (*InitiateExportAgreementsToCSVBadRequest) GetPayload added in v0.69.0

func (*InitiateExportAgreementsToCSVBadRequest) ToJSONString added in v0.69.0

type InitiateExportAgreementsToCSVConflict added in v0.68.0

type InitiateExportAgreementsToCSVConflict struct {
	Payload *legalclientmodels.ErrorEntity
}

InitiateExportAgreementsToCSVConflict handles this case with default header values.

<table><tr><td>NumericErrorCode</td><td>ErrorCode</td></tr><tr><td>40071</td><td>Previous export still running for namespace [{namespace}] with exportId [{exportId}]</td></tr></table>

func NewInitiateExportAgreementsToCSVConflict added in v0.68.0

func NewInitiateExportAgreementsToCSVConflict() *InitiateExportAgreementsToCSVConflict

NewInitiateExportAgreementsToCSVConflict creates a InitiateExportAgreementsToCSVConflict with default headers values

func (*InitiateExportAgreementsToCSVConflict) Error added in v0.68.0

func (*InitiateExportAgreementsToCSVConflict) GetPayload added in v0.68.0

func (*InitiateExportAgreementsToCSVConflict) ToJSONString added in v0.68.0

type InitiateExportAgreementsToCSVNotFound added in v0.68.0

type InitiateExportAgreementsToCSVNotFound struct {
	Payload *legalclientmodels.ErrorEntity
}

InitiateExportAgreementsToCSVNotFound handles this case with default header values.

<table><tr><td>NumericErrorCode</td><td>ErrorCode</td></tr><tr><td>40045</td><td>Policy version with id: [{policyVersionId}] not found on namespace [{namespace}]</td></tr></table>

func NewInitiateExportAgreementsToCSVNotFound added in v0.68.0

func NewInitiateExportAgreementsToCSVNotFound() *InitiateExportAgreementsToCSVNotFound

NewInitiateExportAgreementsToCSVNotFound creates a InitiateExportAgreementsToCSVNotFound with default headers values

func (*InitiateExportAgreementsToCSVNotFound) Error added in v0.68.0

func (*InitiateExportAgreementsToCSVNotFound) GetPayload added in v0.68.0

func (*InitiateExportAgreementsToCSVNotFound) ToJSONString added in v0.68.0

type InitiateExportAgreementsToCSVOK added in v0.68.0

type InitiateExportAgreementsToCSVOK struct {
	Payload *legalclientmodels.InitiateExportAgreementsToCSVResponse
}

InitiateExportAgreementsToCSVOK handles this case with default header values.

successful operation

func NewInitiateExportAgreementsToCSVOK added in v0.68.0

func NewInitiateExportAgreementsToCSVOK() *InitiateExportAgreementsToCSVOK

NewInitiateExportAgreementsToCSVOK creates a InitiateExportAgreementsToCSVOK with default headers values

func (*InitiateExportAgreementsToCSVOK) Error added in v0.68.0

func (*InitiateExportAgreementsToCSVOK) GetPayload added in v0.68.0

func (*InitiateExportAgreementsToCSVOK) ToJSONString added in v0.68.0

func (o *InitiateExportAgreementsToCSVOK) ToJSONString() string

type InitiateExportAgreementsToCSVParams added in v0.68.0

type InitiateExportAgreementsToCSVParams struct {

	/*RetryPolicy*/
	RetryPolicy *utils.Retry
	/*Namespace
	  Namespace

	*/
	Namespace string
	/*End
	  End time of signed_date to retrieve, will use current time if not specified. Using ISO 8601 format yyyy-MM-dd'T'HH:mm:ss'Z', e.g. 2024-01-01T00:00:00Z

	*/
	End *string
	/*PolicyVersionID
	  Policy Version Id

	*/
	PolicyVersionID string
	/*Start
	  Start time of signed_date to retrieve. Using ISO 8601 format yyyy-MM-dd'T'HH:mm:ss'Z', e.g. 2024-01-01T00:00:00Z

	*/
	Start string

	AuthInfoWriter runtime.ClientAuthInfoWriter
	Context        context.Context
	HTTPClient     *http.Client

	// XFlightId is an optional parameter from this SDK
	XFlightId *string
	// contains filtered or unexported fields
}

InitiateExportAgreementsToCSVParams contains all the parameters to send to the API endpoint for the initiate export agreements to csv operation typically these are written to a http.Request

func NewInitiateExportAgreementsToCSVParams added in v0.68.0

func NewInitiateExportAgreementsToCSVParams() *InitiateExportAgreementsToCSVParams

NewInitiateExportAgreementsToCSVParams creates a new InitiateExportAgreementsToCSVParams object with the default values initialized.

func NewInitiateExportAgreementsToCSVParamsWithContext added in v0.68.0

func NewInitiateExportAgreementsToCSVParamsWithContext(ctx context.Context) *InitiateExportAgreementsToCSVParams

NewInitiateExportAgreementsToCSVParamsWithContext creates a new InitiateExportAgreementsToCSVParams object with the default values initialized, and the ability to set a context for a request

func NewInitiateExportAgreementsToCSVParamsWithHTTPClient added in v0.68.0

func NewInitiateExportAgreementsToCSVParamsWithHTTPClient(client *http.Client) *InitiateExportAgreementsToCSVParams

NewInitiateExportAgreementsToCSVParamsWithHTTPClient creates a new InitiateExportAgreementsToCSVParams object with the default values initialized, and the ability to set a custom HTTPClient for a request

func NewInitiateExportAgreementsToCSVParamsWithTimeout added in v0.68.0

func NewInitiateExportAgreementsToCSVParamsWithTimeout(timeout time.Duration) *InitiateExportAgreementsToCSVParams

NewInitiateExportAgreementsToCSVParamsWithTimeout creates a new InitiateExportAgreementsToCSVParams object with the default values initialized, and the ability to set a timeout on a request

func (*InitiateExportAgreementsToCSVParams) SetAuthInfoWriter added in v0.68.0

func (o *InitiateExportAgreementsToCSVParams) SetAuthInfoWriter(authInfoWriter runtime.ClientAuthInfoWriter)

SetAuthInfoWriter adds the authInfoWriter to the initiate export agreements to csv params

func (*InitiateExportAgreementsToCSVParams) SetContext added in v0.68.0

SetContext adds the context to the initiate export agreements to csv params

func (*InitiateExportAgreementsToCSVParams) SetEnd added in v0.69.0

SetEnd adds the end to the initiate export agreements to csv params

func (*InitiateExportAgreementsToCSVParams) SetFlightId added in v0.68.0

func (o *InitiateExportAgreementsToCSVParams) SetFlightId(flightId string)

SetFlightId adds the flightId as the header value for this specific endpoint

func (*InitiateExportAgreementsToCSVParams) SetHTTPClient added in v0.68.0

func (o *InitiateExportAgreementsToCSVParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the initiate export agreements to csv params

func (*InitiateExportAgreementsToCSVParams) SetHTTPClientTransport added in v0.68.0

func (o *InitiateExportAgreementsToCSVParams) SetHTTPClientTransport(roundTripper http.RoundTripper)

SetHTTPClient adds the HTTPClient Transport to the initiate export agreements to csv params

func (*InitiateExportAgreementsToCSVParams) SetNamespace added in v0.68.0

func (o *InitiateExportAgreementsToCSVParams) SetNamespace(namespace string)

SetNamespace adds the namespace to the initiate export agreements to csv params

func (*InitiateExportAgreementsToCSVParams) SetPolicyVersionID added in v0.68.0

func (o *InitiateExportAgreementsToCSVParams) SetPolicyVersionID(policyVersionID string)

SetPolicyVersionID adds the policyVersionId to the initiate export agreements to csv params

func (*InitiateExportAgreementsToCSVParams) SetStart added in v0.69.0

func (o *InitiateExportAgreementsToCSVParams) SetStart(start string)

SetStart adds the start to the initiate export agreements to csv params

func (*InitiateExportAgreementsToCSVParams) SetTimeout added in v0.68.0

func (o *InitiateExportAgreementsToCSVParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the initiate export agreements to csv params

func (*InitiateExportAgreementsToCSVParams) WithContext added in v0.68.0

WithContext adds the context to the initiate export agreements to csv params

func (*InitiateExportAgreementsToCSVParams) WithEnd added in v0.69.0

WithEnd adds the end to the initiate export agreements to csv params

func (*InitiateExportAgreementsToCSVParams) WithHTTPClient added in v0.68.0

WithHTTPClient adds the HTTPClient to the initiate export agreements to csv params

func (*InitiateExportAgreementsToCSVParams) WithNamespace added in v0.68.0

WithNamespace adds the namespace to the initiate export agreements to csv params

func (*InitiateExportAgreementsToCSVParams) WithPolicyVersionID added in v0.68.0

func (o *InitiateExportAgreementsToCSVParams) WithPolicyVersionID(policyVersionID string) *InitiateExportAgreementsToCSVParams

WithPolicyVersionID adds the policyVersionID to the initiate export agreements to csv params

func (*InitiateExportAgreementsToCSVParams) WithStart added in v0.69.0

WithStart adds the start to the initiate export agreements to csv params

func (*InitiateExportAgreementsToCSVParams) WithTimeout added in v0.68.0

WithTimeout adds the timeout to the initiate export agreements to csv params

func (*InitiateExportAgreementsToCSVParams) WriteToRequest added in v0.68.0

WriteToRequest writes these params to a swagger request

type InitiateExportAgreementsToCSVReader added in v0.68.0

type InitiateExportAgreementsToCSVReader struct {
	// contains filtered or unexported fields
}

InitiateExportAgreementsToCSVReader is a Reader for the InitiateExportAgreementsToCSV structure.

func (*InitiateExportAgreementsToCSVReader) ReadResponse added in v0.68.0

func (o *InitiateExportAgreementsToCSVReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type RetrieveAcceptedAgreementsForMultiUsersOK added in v0.40.0

type RetrieveAcceptedAgreementsForMultiUsersOK struct {
	Payload []*legalclientmodels.UserAgreementsResponse
}

RetrieveAcceptedAgreementsForMultiUsersOK handles this case with default header values.

successful operation

func NewRetrieveAcceptedAgreementsForMultiUsersOK added in v0.40.0

func NewRetrieveAcceptedAgreementsForMultiUsersOK() *RetrieveAcceptedAgreementsForMultiUsersOK

NewRetrieveAcceptedAgreementsForMultiUsersOK creates a RetrieveAcceptedAgreementsForMultiUsersOK with default headers values

func (*RetrieveAcceptedAgreementsForMultiUsersOK) Error added in v0.40.0

func (*RetrieveAcceptedAgreementsForMultiUsersOK) GetPayload added in v0.40.0

func (*RetrieveAcceptedAgreementsForMultiUsersOK) ToJSONString added in v0.40.0

type RetrieveAcceptedAgreementsForMultiUsersParams added in v0.40.0

type RetrieveAcceptedAgreementsForMultiUsersParams struct {

	/*RetryPolicy*/
	RetryPolicy *utils.Retry
	/*Body*/
	Body *legalclientmodels.UsersAgreementsRequest
	/*Namespace
	  Namespace

	*/
	Namespace string

	AuthInfoWriter runtime.ClientAuthInfoWriter
	Context        context.Context
	HTTPClient     *http.Client

	// XFlightId is an optional parameter from this SDK
	XFlightId *string
	// contains filtered or unexported fields
}

RetrieveAcceptedAgreementsForMultiUsersParams contains all the parameters to send to the API endpoint for the retrieve accepted agreements for multi users operation typically these are written to a http.Request

func NewRetrieveAcceptedAgreementsForMultiUsersParams added in v0.40.0

func NewRetrieveAcceptedAgreementsForMultiUsersParams() *RetrieveAcceptedAgreementsForMultiUsersParams

NewRetrieveAcceptedAgreementsForMultiUsersParams creates a new RetrieveAcceptedAgreementsForMultiUsersParams object with the default values initialized.

func NewRetrieveAcceptedAgreementsForMultiUsersParamsWithContext added in v0.40.0

func NewRetrieveAcceptedAgreementsForMultiUsersParamsWithContext(ctx context.Context) *RetrieveAcceptedAgreementsForMultiUsersParams

NewRetrieveAcceptedAgreementsForMultiUsersParamsWithContext creates a new RetrieveAcceptedAgreementsForMultiUsersParams object with the default values initialized, and the ability to set a context for a request

func NewRetrieveAcceptedAgreementsForMultiUsersParamsWithHTTPClient added in v0.40.0

func NewRetrieveAcceptedAgreementsForMultiUsersParamsWithHTTPClient(client *http.Client) *RetrieveAcceptedAgreementsForMultiUsersParams

NewRetrieveAcceptedAgreementsForMultiUsersParamsWithHTTPClient creates a new RetrieveAcceptedAgreementsForMultiUsersParams object with the default values initialized, and the ability to set a custom HTTPClient for a request

func NewRetrieveAcceptedAgreementsForMultiUsersParamsWithTimeout added in v0.40.0

func NewRetrieveAcceptedAgreementsForMultiUsersParamsWithTimeout(timeout time.Duration) *RetrieveAcceptedAgreementsForMultiUsersParams

NewRetrieveAcceptedAgreementsForMultiUsersParamsWithTimeout creates a new RetrieveAcceptedAgreementsForMultiUsersParams object with the default values initialized, and the ability to set a timeout on a request

func (*RetrieveAcceptedAgreementsForMultiUsersParams) SetAuthInfoWriter added in v0.40.0

func (o *RetrieveAcceptedAgreementsForMultiUsersParams) SetAuthInfoWriter(authInfoWriter runtime.ClientAuthInfoWriter)

SetAuthInfoWriter adds the authInfoWriter to the retrieve accepted agreements for multi users params

func (*RetrieveAcceptedAgreementsForMultiUsersParams) SetBody added in v0.40.0

SetBody adds the body to the retrieve accepted agreements for multi users params

func (*RetrieveAcceptedAgreementsForMultiUsersParams) SetContext added in v0.40.0

SetContext adds the context to the retrieve accepted agreements for multi users params

func (*RetrieveAcceptedAgreementsForMultiUsersParams) SetFlightId added in v0.63.0

func (o *RetrieveAcceptedAgreementsForMultiUsersParams) SetFlightId(flightId string)

SetFlightId adds the flightId as the header value for this specific endpoint

func (*RetrieveAcceptedAgreementsForMultiUsersParams) SetHTTPClient added in v0.40.0

func (o *RetrieveAcceptedAgreementsForMultiUsersParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the retrieve accepted agreements for multi users params

func (*RetrieveAcceptedAgreementsForMultiUsersParams) SetHTTPClientTransport added in v0.40.0

func (o *RetrieveAcceptedAgreementsForMultiUsersParams) SetHTTPClientTransport(roundTripper http.RoundTripper)

SetHTTPClient adds the HTTPClient Transport to the retrieve accepted agreements for multi users params

func (*RetrieveAcceptedAgreementsForMultiUsersParams) SetNamespace added in v0.40.0

func (o *RetrieveAcceptedAgreementsForMultiUsersParams) SetNamespace(namespace string)

SetNamespace adds the namespace to the retrieve accepted agreements for multi users params

func (*RetrieveAcceptedAgreementsForMultiUsersParams) SetTimeout added in v0.40.0

SetTimeout adds the timeout to the retrieve accepted agreements for multi users params

func (*RetrieveAcceptedAgreementsForMultiUsersParams) WithBody added in v0.40.0

WithBody adds the body to the retrieve accepted agreements for multi users params

func (*RetrieveAcceptedAgreementsForMultiUsersParams) WithContext added in v0.40.0

WithContext adds the context to the retrieve accepted agreements for multi users params

func (*RetrieveAcceptedAgreementsForMultiUsersParams) WithHTTPClient added in v0.40.0

WithHTTPClient adds the HTTPClient to the retrieve accepted agreements for multi users params

func (*RetrieveAcceptedAgreementsForMultiUsersParams) WithNamespace added in v0.40.0

WithNamespace adds the namespace to the retrieve accepted agreements for multi users params

func (*RetrieveAcceptedAgreementsForMultiUsersParams) WithTimeout added in v0.40.0

WithTimeout adds the timeout to the retrieve accepted agreements for multi users params

func (*RetrieveAcceptedAgreementsForMultiUsersParams) WriteToRequest added in v0.40.0

WriteToRequest writes these params to a swagger request

type RetrieveAcceptedAgreementsForMultiUsersReader added in v0.40.0

type RetrieveAcceptedAgreementsForMultiUsersReader struct {
	// contains filtered or unexported fields
}

RetrieveAcceptedAgreementsForMultiUsersReader is a Reader for the RetrieveAcceptedAgreementsForMultiUsers structure.

func (*RetrieveAcceptedAgreementsForMultiUsersReader) ReadResponse added in v0.40.0

func (o *RetrieveAcceptedAgreementsForMultiUsersReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type RetrieveAcceptedAgreementsOK added in v0.84.0

type RetrieveAcceptedAgreementsOK struct {
	Payload []*legalclientmodels.RetrieveAcceptedAgreementResponse
}

RetrieveAcceptedAgreementsOK handles this case with default header values.

successful operation

func NewRetrieveAcceptedAgreementsOK added in v0.84.0

func NewRetrieveAcceptedAgreementsOK() *RetrieveAcceptedAgreementsOK

NewRetrieveAcceptedAgreementsOK creates a RetrieveAcceptedAgreementsOK with default headers values

func (*RetrieveAcceptedAgreementsOK) Error added in v0.84.0

func (*RetrieveAcceptedAgreementsOK) GetPayload added in v0.84.0

func (*RetrieveAcceptedAgreementsOK) ToJSONString added in v0.84.0

func (o *RetrieveAcceptedAgreementsOK) ToJSONString() string

type RetrieveAcceptedAgreementsParams added in v0.84.0

type RetrieveAcceptedAgreementsParams struct {

	/*RetryPolicy*/
	RetryPolicy *utils.Retry
	/*Namespace
	  Namespace

	*/
	Namespace string
	/*UserID
	  User Id

	*/
	UserID string
	/*ExcludeOtherNamespacesPolicies
	  If it is true, API will only query the policy in this path namespace

	*/
	ExcludeOtherNamespacesPolicies *bool

	AuthInfoWriter runtime.ClientAuthInfoWriter
	Context        context.Context
	HTTPClient     *http.Client

	// XFlightId is an optional parameter from this SDK
	XFlightId *string
	// contains filtered or unexported fields
}

RetrieveAcceptedAgreementsParams contains all the parameters to send to the API endpoint for the retrieve accepted agreements operation typically these are written to a http.Request

func NewRetrieveAcceptedAgreementsParams added in v0.84.0

func NewRetrieveAcceptedAgreementsParams() *RetrieveAcceptedAgreementsParams

NewRetrieveAcceptedAgreementsParams creates a new RetrieveAcceptedAgreementsParams object with the default values initialized.

func NewRetrieveAcceptedAgreementsParamsWithContext added in v0.84.0

func NewRetrieveAcceptedAgreementsParamsWithContext(ctx context.Context) *RetrieveAcceptedAgreementsParams

NewRetrieveAcceptedAgreementsParamsWithContext creates a new RetrieveAcceptedAgreementsParams object with the default values initialized, and the ability to set a context for a request

func NewRetrieveAcceptedAgreementsParamsWithHTTPClient added in v0.84.0

func NewRetrieveAcceptedAgreementsParamsWithHTTPClient(client *http.Client) *RetrieveAcceptedAgreementsParams

NewRetrieveAcceptedAgreementsParamsWithHTTPClient creates a new RetrieveAcceptedAgreementsParams object with the default values initialized, and the ability to set a custom HTTPClient for a request

func NewRetrieveAcceptedAgreementsParamsWithTimeout added in v0.84.0

func NewRetrieveAcceptedAgreementsParamsWithTimeout(timeout time.Duration) *RetrieveAcceptedAgreementsParams

NewRetrieveAcceptedAgreementsParamsWithTimeout creates a new RetrieveAcceptedAgreementsParams object with the default values initialized, and the ability to set a timeout on a request

func (*RetrieveAcceptedAgreementsParams) SetAuthInfoWriter added in v0.84.0

func (o *RetrieveAcceptedAgreementsParams) SetAuthInfoWriter(authInfoWriter runtime.ClientAuthInfoWriter)

SetAuthInfoWriter adds the authInfoWriter to the retrieve accepted agreements params

func (*RetrieveAcceptedAgreementsParams) SetContext added in v0.84.0

SetContext adds the context to the retrieve accepted agreements params

func (*RetrieveAcceptedAgreementsParams) SetExcludeOtherNamespacesPolicies added in v0.84.0

func (o *RetrieveAcceptedAgreementsParams) SetExcludeOtherNamespacesPolicies(excludeOtherNamespacesPolicies *bool)

SetExcludeOtherNamespacesPolicies adds the excludeOtherNamespacesPolicies to the retrieve accepted agreements params

func (*RetrieveAcceptedAgreementsParams) SetFlightId added in v0.84.0

func (o *RetrieveAcceptedAgreementsParams) SetFlightId(flightId string)

SetFlightId adds the flightId as the header value for this specific endpoint

func (*RetrieveAcceptedAgreementsParams) SetHTTPClient added in v0.84.0

func (o *RetrieveAcceptedAgreementsParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the retrieve accepted agreements params

func (*RetrieveAcceptedAgreementsParams) SetHTTPClientTransport added in v0.84.0

func (o *RetrieveAcceptedAgreementsParams) SetHTTPClientTransport(roundTripper http.RoundTripper)

SetHTTPClient adds the HTTPClient Transport to the retrieve accepted agreements params

func (*RetrieveAcceptedAgreementsParams) SetNamespace added in v0.84.0

func (o *RetrieveAcceptedAgreementsParams) SetNamespace(namespace string)

SetNamespace adds the namespace to the retrieve accepted agreements params

func (*RetrieveAcceptedAgreementsParams) SetTimeout added in v0.84.0

func (o *RetrieveAcceptedAgreementsParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the retrieve accepted agreements params

func (*RetrieveAcceptedAgreementsParams) SetUserID added in v0.84.0

func (o *RetrieveAcceptedAgreementsParams) SetUserID(userID string)

SetUserID adds the userId to the retrieve accepted agreements params

func (*RetrieveAcceptedAgreementsParams) WithContext added in v0.84.0

WithContext adds the context to the retrieve accepted agreements params

func (*RetrieveAcceptedAgreementsParams) WithExcludeOtherNamespacesPolicies added in v0.84.0

func (o *RetrieveAcceptedAgreementsParams) WithExcludeOtherNamespacesPolicies(excludeOtherNamespacesPolicies *bool) *RetrieveAcceptedAgreementsParams

WithExcludeOtherNamespacesPolicies adds the excludeOtherNamespacesPolicies to the retrieve accepted agreements params

func (*RetrieveAcceptedAgreementsParams) WithHTTPClient added in v0.84.0

WithHTTPClient adds the HTTPClient to the retrieve accepted agreements params

func (*RetrieveAcceptedAgreementsParams) WithNamespace added in v0.84.0

WithNamespace adds the namespace to the retrieve accepted agreements params

func (*RetrieveAcceptedAgreementsParams) WithTimeout added in v0.84.0

WithTimeout adds the timeout to the retrieve accepted agreements params

func (*RetrieveAcceptedAgreementsParams) WithUserID added in v0.84.0

WithUserID adds the userID to the retrieve accepted agreements params

func (*RetrieveAcceptedAgreementsParams) WriteToRequest added in v0.84.0

WriteToRequest writes these params to a swagger request

type RetrieveAcceptedAgreementsReader added in v0.84.0

type RetrieveAcceptedAgreementsReader struct {
	// contains filtered or unexported fields
}

RetrieveAcceptedAgreementsReader is a Reader for the RetrieveAcceptedAgreements structure.

func (*RetrieveAcceptedAgreementsReader) ReadResponse added in v0.84.0

func (o *RetrieveAcceptedAgreementsReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type RetrieveAllUsersByPolicyVersionNotFound added in v0.84.0

type RetrieveAllUsersByPolicyVersionNotFound struct {
	Payload *legalclientmodels.ErrorEntity
}

RetrieveAllUsersByPolicyVersionNotFound handles this case with default header values.

<table><tr><td>NumericErrorCode</td><td>ErrorCode</td></tr><tr><td>40035</td><td>errors.net.accelbyte.platform.legal.policy_version_not_found</td></tr></table>

func NewRetrieveAllUsersByPolicyVersionNotFound added in v0.84.0

func NewRetrieveAllUsersByPolicyVersionNotFound() *RetrieveAllUsersByPolicyVersionNotFound

NewRetrieveAllUsersByPolicyVersionNotFound creates a RetrieveAllUsersByPolicyVersionNotFound with default headers values

func (*RetrieveAllUsersByPolicyVersionNotFound) Error added in v0.84.0

func (*RetrieveAllUsersByPolicyVersionNotFound) GetPayload added in v0.84.0

func (*RetrieveAllUsersByPolicyVersionNotFound) ToJSONString added in v0.84.0

type RetrieveAllUsersByPolicyVersionOK added in v0.84.0

type RetrieveAllUsersByPolicyVersionOK struct {
	Payload *legalclientmodels.PagedRetrieveUserAcceptedAgreementResponse
}

RetrieveAllUsersByPolicyVersionOK handles this case with default header values.

successful operation

func NewRetrieveAllUsersByPolicyVersionOK added in v0.84.0

func NewRetrieveAllUsersByPolicyVersionOK() *RetrieveAllUsersByPolicyVersionOK

NewRetrieveAllUsersByPolicyVersionOK creates a RetrieveAllUsersByPolicyVersionOK with default headers values

func (*RetrieveAllUsersByPolicyVersionOK) Error added in v0.84.0

func (*RetrieveAllUsersByPolicyVersionOK) GetPayload added in v0.84.0

func (*RetrieveAllUsersByPolicyVersionOK) ToJSONString added in v0.84.0

func (o *RetrieveAllUsersByPolicyVersionOK) ToJSONString() string

type RetrieveAllUsersByPolicyVersionParams added in v0.84.0

type RetrieveAllUsersByPolicyVersionParams struct {

	/*RetryPolicy*/
	RetryPolicy *utils.Retry
	/*Namespace
	  Namespace

	*/
	Namespace string
	/*ConvertGameUserID
	  [Only for publisher legal scenario] If it is true, when a game user accept this publisher legal, API will return publisher user id

	*/
	ConvertGameUserID *bool
	/*Keyword
	  display name or email or username

	*/
	Keyword *string
	/*Limit
	  limit

	*/
	Limit *int32
	/*Offset
	  offset

	*/
	Offset *int32
	/*PolicyVersionID*/
	PolicyVersionID string

	AuthInfoWriter runtime.ClientAuthInfoWriter
	Context        context.Context
	HTTPClient     *http.Client

	// XFlightId is an optional parameter from this SDK
	XFlightId *string
	// contains filtered or unexported fields
}

RetrieveAllUsersByPolicyVersionParams contains all the parameters to send to the API endpoint for the retrieve all users by policy version operation typically these are written to a http.Request

func NewRetrieveAllUsersByPolicyVersionParams added in v0.84.0

func NewRetrieveAllUsersByPolicyVersionParams() *RetrieveAllUsersByPolicyVersionParams

NewRetrieveAllUsersByPolicyVersionParams creates a new RetrieveAllUsersByPolicyVersionParams object with the default values initialized.

func NewRetrieveAllUsersByPolicyVersionParamsWithContext added in v0.84.0

func NewRetrieveAllUsersByPolicyVersionParamsWithContext(ctx context.Context) *RetrieveAllUsersByPolicyVersionParams

NewRetrieveAllUsersByPolicyVersionParamsWithContext creates a new RetrieveAllUsersByPolicyVersionParams object with the default values initialized, and the ability to set a context for a request

func NewRetrieveAllUsersByPolicyVersionParamsWithHTTPClient added in v0.84.0

func NewRetrieveAllUsersByPolicyVersionParamsWithHTTPClient(client *http.Client) *RetrieveAllUsersByPolicyVersionParams

NewRetrieveAllUsersByPolicyVersionParamsWithHTTPClient creates a new RetrieveAllUsersByPolicyVersionParams object with the default values initialized, and the ability to set a custom HTTPClient for a request

func NewRetrieveAllUsersByPolicyVersionParamsWithTimeout added in v0.84.0

func NewRetrieveAllUsersByPolicyVersionParamsWithTimeout(timeout time.Duration) *RetrieveAllUsersByPolicyVersionParams

NewRetrieveAllUsersByPolicyVersionParamsWithTimeout creates a new RetrieveAllUsersByPolicyVersionParams object with the default values initialized, and the ability to set a timeout on a request

func (*RetrieveAllUsersByPolicyVersionParams) SetAuthInfoWriter added in v0.84.0

func (o *RetrieveAllUsersByPolicyVersionParams) SetAuthInfoWriter(authInfoWriter runtime.ClientAuthInfoWriter)

SetAuthInfoWriter adds the authInfoWriter to the retrieve all users by policy version params

func (*RetrieveAllUsersByPolicyVersionParams) SetContext added in v0.84.0

SetContext adds the context to the retrieve all users by policy version params

func (*RetrieveAllUsersByPolicyVersionParams) SetConvertGameUserID added in v0.84.0

func (o *RetrieveAllUsersByPolicyVersionParams) SetConvertGameUserID(convertGameUserID *bool)

SetConvertGameUserID adds the convertGameUserId to the retrieve all users by policy version params

func (*RetrieveAllUsersByPolicyVersionParams) SetFlightId added in v0.84.0

func (o *RetrieveAllUsersByPolicyVersionParams) SetFlightId(flightId string)

SetFlightId adds the flightId as the header value for this specific endpoint

func (*RetrieveAllUsersByPolicyVersionParams) SetHTTPClient added in v0.84.0

func (o *RetrieveAllUsersByPolicyVersionParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the retrieve all users by policy version params

func (*RetrieveAllUsersByPolicyVersionParams) SetHTTPClientTransport added in v0.84.0

func (o *RetrieveAllUsersByPolicyVersionParams) SetHTTPClientTransport(roundTripper http.RoundTripper)

SetHTTPClient adds the HTTPClient Transport to the retrieve all users by policy version params

func (*RetrieveAllUsersByPolicyVersionParams) SetKeyword added in v0.84.0

func (o *RetrieveAllUsersByPolicyVersionParams) SetKeyword(keyword *string)

SetKeyword adds the keyword to the retrieve all users by policy version params

func (*RetrieveAllUsersByPolicyVersionParams) SetLimit added in v0.84.0

func (o *RetrieveAllUsersByPolicyVersionParams) SetLimit(limit *int32)

SetLimit adds the limit to the retrieve all users by policy version params

func (*RetrieveAllUsersByPolicyVersionParams) SetNamespace added in v0.84.0

func (o *RetrieveAllUsersByPolicyVersionParams) SetNamespace(namespace string)

SetNamespace adds the namespace to the retrieve all users by policy version params

func (*RetrieveAllUsersByPolicyVersionParams) SetOffset added in v0.84.0

func (o *RetrieveAllUsersByPolicyVersionParams) SetOffset(offset *int32)

SetOffset adds the offset to the retrieve all users by policy version params

func (*RetrieveAllUsersByPolicyVersionParams) SetPolicyVersionID added in v0.84.0

func (o *RetrieveAllUsersByPolicyVersionParams) SetPolicyVersionID(policyVersionID string)

SetPolicyVersionID adds the policyVersionId to the retrieve all users by policy version params

func (*RetrieveAllUsersByPolicyVersionParams) SetTimeout added in v0.84.0

func (o *RetrieveAllUsersByPolicyVersionParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the retrieve all users by policy version params

func (*RetrieveAllUsersByPolicyVersionParams) WithContext added in v0.84.0

WithContext adds the context to the retrieve all users by policy version params

func (*RetrieveAllUsersByPolicyVersionParams) WithConvertGameUserID added in v0.84.0

func (o *RetrieveAllUsersByPolicyVersionParams) WithConvertGameUserID(convertGameUserID *bool) *RetrieveAllUsersByPolicyVersionParams

WithConvertGameUserID adds the convertGameUserID to the retrieve all users by policy version params

func (*RetrieveAllUsersByPolicyVersionParams) WithHTTPClient added in v0.84.0

WithHTTPClient adds the HTTPClient to the retrieve all users by policy version params

func (*RetrieveAllUsersByPolicyVersionParams) WithKeyword added in v0.84.0

WithKeyword adds the keyword to the retrieve all users by policy version params

func (*RetrieveAllUsersByPolicyVersionParams) WithLimit added in v0.84.0

WithLimit adds the limit to the retrieve all users by policy version params

func (*RetrieveAllUsersByPolicyVersionParams) WithNamespace added in v0.84.0

WithNamespace adds the namespace to the retrieve all users by policy version params

func (*RetrieveAllUsersByPolicyVersionParams) WithOffset added in v0.84.0

WithOffset adds the offset to the retrieve all users by policy version params

func (*RetrieveAllUsersByPolicyVersionParams) WithPolicyVersionID added in v0.84.0

WithPolicyVersionID adds the policyVersionID to the retrieve all users by policy version params

func (*RetrieveAllUsersByPolicyVersionParams) WithTimeout added in v0.84.0

WithTimeout adds the timeout to the retrieve all users by policy version params

func (*RetrieveAllUsersByPolicyVersionParams) WriteToRequest added in v0.84.0

WriteToRequest writes these params to a swagger request

type RetrieveAllUsersByPolicyVersionReader added in v0.84.0

type RetrieveAllUsersByPolicyVersionReader struct {
	// contains filtered or unexported fields
}

RetrieveAllUsersByPolicyVersionReader is a Reader for the RetrieveAllUsersByPolicyVersion structure.

func (*RetrieveAllUsersByPolicyVersionReader) ReadResponse added in v0.84.0

func (o *RetrieveAllUsersByPolicyVersionReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

Jump to