base_legal_policies

package
v0.86.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 13, 2026 License: MIT Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client for base legal policies API

func (*Client) OldCreatePolicy deprecated added in v0.84.0

Deprecated: 2022-08-10 - Use OldCreatePolicyShort instead.

OldCreatePolicy create a base legal policy Create a legal policy. Note:

  • countryType field only accept COUNTRY or COUNTRY_GROUP.
  • COUNTRY_GROUP countryType requires the countryGroupName and affectedCountries fields to be provided.

* policy with COUNTRY_GROUP type include multiple countries and apply the same policy across the entire list of countries

func (*Client) OldCreatePolicyShort added in v0.84.0

func (a *Client) OldCreatePolicyShort(params *OldCreatePolicyParams, authInfo runtime.ClientAuthInfoWriter) (*OldCreatePolicyCreated, error)

OldCreatePolicyShort create a base legal policy Create a legal policy. Note:

  • countryType field only accept COUNTRY or COUNTRY_GROUP.
  • COUNTRY_GROUP countryType requires the countryGroupName and affectedCountries fields to be provided.

* policy with COUNTRY_GROUP type include multiple countries and apply the same policy across the entire list of countries

func (*Client) OldPartialUpdatePolicy deprecated added in v0.84.0

Deprecated: 2022-08-10 - Use OldPartialUpdatePolicyShort instead.

OldPartialUpdatePolicy update base legal policy Update an existing base policy. Note:

  • countryType field only accept COUNTRY or COUNTRY_GROUP.
  • COUNTRY_GROUP countryType requires the countryGroupName and affectedCountries fields to be provided.

* policy with COUNTRY_GROUP type include multiple countries and apply the same policy across the entire list of countries

func (*Client) OldPartialUpdatePolicyShort added in v0.84.0

func (a *Client) OldPartialUpdatePolicyShort(params *OldPartialUpdatePolicyParams, authInfo runtime.ClientAuthInfoWriter) (*OldPartialUpdatePolicyOK, error)

OldPartialUpdatePolicyShort update base legal policy Update an existing base policy. Note:

  • countryType field only accept COUNTRY or COUNTRY_GROUP.
  • COUNTRY_GROUP countryType requires the countryGroupName and affectedCountries fields to be provided.

* policy with COUNTRY_GROUP type include multiple countries and apply the same policy across the entire list of countries

func (*Client) OldRetrieveAllPolicyTypes deprecated added in v0.84.0

func (a *Client) OldRetrieveAllPolicyTypes(params *OldRetrieveAllPolicyTypesParams, authInfo runtime.ClientAuthInfoWriter) (*OldRetrieveAllPolicyTypesOK, error)

Deprecated: 2022-08-10 - Use OldRetrieveAllPolicyTypesShort instead.

OldRetrieveAllPolicyTypes retrieve all policy type Retrieve all supported policy types.

func (*Client) OldRetrieveAllPolicyTypesShort added in v0.84.0

func (a *Client) OldRetrieveAllPolicyTypesShort(params *OldRetrieveAllPolicyTypesParams, authInfo runtime.ClientAuthInfoWriter) (*OldRetrieveAllPolicyTypesOK, error)

OldRetrieveAllPolicyTypesShort retrieve all policy type Retrieve all supported policy types.

func (*Client) OldRetrievePolicyCountry deprecated added in v0.84.0

Deprecated: 2022-08-10 - Use OldRetrievePolicyCountryShort instead.

OldRetrievePolicyCountry retrieve a base legal policy based on a particular country Retrieve a Base Legal Policy based on a Particular Country.

func (*Client) OldRetrievePolicyCountryShort added in v0.84.0

func (a *Client) OldRetrievePolicyCountryShort(params *OldRetrievePolicyCountryParams, authInfo runtime.ClientAuthInfoWriter) (*OldRetrievePolicyCountryOK, error)

OldRetrievePolicyCountryShort retrieve a base legal policy based on a particular country Retrieve a Base Legal Policy based on a Particular Country.

func (*Client) OldRetrieveSinglePolicy deprecated added in v0.84.0

Deprecated: 2022-08-10 - Use OldRetrieveSinglePolicyShort instead.

OldRetrieveSinglePolicy retrieve a base legal policy Retrieve a base policy.

func (*Client) OldRetrieveSinglePolicyShort added in v0.84.0

func (a *Client) OldRetrieveSinglePolicyShort(params *OldRetrieveSinglePolicyParams, authInfo runtime.ClientAuthInfoWriter) (*OldRetrieveSinglePolicyOK, error)

OldRetrieveSinglePolicyShort retrieve a base legal policy Retrieve a base policy.

func (*Client) RetrieveAllLegalPolicies deprecated

func (a *Client) RetrieveAllLegalPolicies(params *RetrieveAllLegalPoliciesParams, authInfo runtime.ClientAuthInfoWriter) (*RetrieveAllLegalPoliciesOK, error)

Deprecated: 2022-08-10 - Use RetrieveAllLegalPoliciesShort instead.

RetrieveAllLegalPolicies retrieve all base legal policy Retrieve all base policies.

func (*Client) RetrieveAllLegalPoliciesShort added in v0.8.0

func (a *Client) RetrieveAllLegalPoliciesShort(params *RetrieveAllLegalPoliciesParams, authInfo runtime.ClientAuthInfoWriter) (*RetrieveAllLegalPoliciesOK, error)

RetrieveAllLegalPoliciesShort retrieve all base legal policy Retrieve all base policies.

func (*Client) SetTransport

func (a *Client) SetTransport(transport runtime.ClientTransport)

SetTransport changes the transport on the client

type ClientService

type ClientService interface {
	RetrieveAllLegalPolicies(params *RetrieveAllLegalPoliciesParams, authInfo runtime.ClientAuthInfoWriter) (*RetrieveAllLegalPoliciesOK, error)
	RetrieveAllLegalPoliciesShort(params *RetrieveAllLegalPoliciesParams, authInfo runtime.ClientAuthInfoWriter) (*RetrieveAllLegalPoliciesOK, error)
	OldCreatePolicy(params *OldCreatePolicyParams, authInfo runtime.ClientAuthInfoWriter) (*OldCreatePolicyCreated, *OldCreatePolicyBadRequest, *OldCreatePolicyNotFound, *OldCreatePolicyUnprocessableEntity, error)
	OldCreatePolicyShort(params *OldCreatePolicyParams, authInfo runtime.ClientAuthInfoWriter) (*OldCreatePolicyCreated, error)
	OldRetrieveSinglePolicy(params *OldRetrieveSinglePolicyParams, authInfo runtime.ClientAuthInfoWriter) (*OldRetrieveSinglePolicyOK, *OldRetrieveSinglePolicyNotFound, error)
	OldRetrieveSinglePolicyShort(params *OldRetrieveSinglePolicyParams, authInfo runtime.ClientAuthInfoWriter) (*OldRetrieveSinglePolicyOK, error)
	OldPartialUpdatePolicy(params *OldPartialUpdatePolicyParams, authInfo runtime.ClientAuthInfoWriter) (*OldPartialUpdatePolicyOK, *OldPartialUpdatePolicyBadRequest, *OldPartialUpdatePolicyNotFound, error)
	OldPartialUpdatePolicyShort(params *OldPartialUpdatePolicyParams, authInfo runtime.ClientAuthInfoWriter) (*OldPartialUpdatePolicyOK, error)
	OldRetrievePolicyCountry(params *OldRetrievePolicyCountryParams, authInfo runtime.ClientAuthInfoWriter) (*OldRetrievePolicyCountryOK, *OldRetrievePolicyCountryNotFound, error)
	OldRetrievePolicyCountryShort(params *OldRetrievePolicyCountryParams, authInfo runtime.ClientAuthInfoWriter) (*OldRetrievePolicyCountryOK, error)
	OldRetrieveAllPolicyTypes(params *OldRetrieveAllPolicyTypesParams, authInfo runtime.ClientAuthInfoWriter) (*OldRetrieveAllPolicyTypesOK, error)
	OldRetrieveAllPolicyTypesShort(params *OldRetrieveAllPolicyTypesParams, authInfo runtime.ClientAuthInfoWriter) (*OldRetrieveAllPolicyTypesOK, error)

	SetTransport(transport runtime.ClientTransport)
}

ClientService is the interface for Client methods

func New

func New(transport runtime.ClientTransport, formats strfmt.Registry) ClientService

New creates a new base legal policies API client.

type OldCreatePolicyBadRequest added in v0.84.0

type OldCreatePolicyBadRequest struct {
	Payload *legalclientmodels.ErrorEntity
}

OldCreatePolicyBadRequest handles this case with default header values.

<table><tr><td>NumericErrorCode</td><td>ErrorCode</td></tr><tr><td>40038</td><td>errors.net.accelbyte.platform.legal.invalid_affected_client_id</td></tr><tr><td>40026</td><td>errors.net.accelbyte.platform.legal.not_allow_create_studio_policy</td></tr></table>

func NewOldCreatePolicyBadRequest added in v0.84.0

func NewOldCreatePolicyBadRequest() *OldCreatePolicyBadRequest

NewOldCreatePolicyBadRequest creates a OldCreatePolicyBadRequest with default headers values

func (*OldCreatePolicyBadRequest) Error added in v0.84.0

func (o *OldCreatePolicyBadRequest) Error() string

func (*OldCreatePolicyBadRequest) GetPayload added in v0.84.0

func (*OldCreatePolicyBadRequest) ToJSONString added in v0.84.0

func (o *OldCreatePolicyBadRequest) ToJSONString() string

type OldCreatePolicyCreated added in v0.84.0

type OldCreatePolicyCreated struct {
	Payload *legalclientmodels.CreateBasePolicyResponse
}

OldCreatePolicyCreated handles this case with default header values.

successful operation

func NewOldCreatePolicyCreated added in v0.84.0

func NewOldCreatePolicyCreated() *OldCreatePolicyCreated

NewOldCreatePolicyCreated creates a OldCreatePolicyCreated with default headers values

func (*OldCreatePolicyCreated) Error added in v0.84.0

func (o *OldCreatePolicyCreated) Error() string

func (*OldCreatePolicyCreated) GetPayload added in v0.84.0

func (*OldCreatePolicyCreated) ToJSONString added in v0.84.0

func (o *OldCreatePolicyCreated) ToJSONString() string

type OldCreatePolicyNotFound added in v0.84.0

type OldCreatePolicyNotFound struct {
	Payload *legalclientmodels.ErrorEntity
}

OldCreatePolicyNotFound handles this case with default header values.

<table><tr><td>NumericErrorCode</td><td>ErrorCode</td></tr><tr><td>40030</td><td>errors.net.accelbyte.platform.legal.policy_type_not_exist</td></tr></table>

func NewOldCreatePolicyNotFound added in v0.84.0

func NewOldCreatePolicyNotFound() *OldCreatePolicyNotFound

NewOldCreatePolicyNotFound creates a OldCreatePolicyNotFound with default headers values

func (*OldCreatePolicyNotFound) Error added in v0.84.0

func (o *OldCreatePolicyNotFound) Error() string

func (*OldCreatePolicyNotFound) GetPayload added in v0.84.0

func (*OldCreatePolicyNotFound) ToJSONString added in v0.84.0

func (o *OldCreatePolicyNotFound) ToJSONString() string

type OldCreatePolicyParams added in v0.84.0

type OldCreatePolicyParams struct {

	/*RetryPolicy*/
	RetryPolicy *utils.Retry
	/*Body*/
	Body *legalclientmodels.CreateBasePolicyRequest

	AuthInfoWriter runtime.ClientAuthInfoWriter
	Context        context.Context
	HTTPClient     *http.Client

	// XFlightId is an optional parameter from this SDK
	XFlightId *string
	// contains filtered or unexported fields
}

OldCreatePolicyParams contains all the parameters to send to the API endpoint for the old create policy operation typically these are written to a http.Request

func NewOldCreatePolicyParams added in v0.84.0

func NewOldCreatePolicyParams() *OldCreatePolicyParams

NewOldCreatePolicyParams creates a new OldCreatePolicyParams object with the default values initialized.

func NewOldCreatePolicyParamsWithContext added in v0.84.0

func NewOldCreatePolicyParamsWithContext(ctx context.Context) *OldCreatePolicyParams

NewOldCreatePolicyParamsWithContext creates a new OldCreatePolicyParams object with the default values initialized, and the ability to set a context for a request

func NewOldCreatePolicyParamsWithHTTPClient added in v0.84.0

func NewOldCreatePolicyParamsWithHTTPClient(client *http.Client) *OldCreatePolicyParams

NewOldCreatePolicyParamsWithHTTPClient creates a new OldCreatePolicyParams object with the default values initialized, and the ability to set a custom HTTPClient for a request

func NewOldCreatePolicyParamsWithTimeout added in v0.84.0

func NewOldCreatePolicyParamsWithTimeout(timeout time.Duration) *OldCreatePolicyParams

NewOldCreatePolicyParamsWithTimeout creates a new OldCreatePolicyParams object with the default values initialized, and the ability to set a timeout on a request

func (*OldCreatePolicyParams) SetAuthInfoWriter added in v0.84.0

func (o *OldCreatePolicyParams) SetAuthInfoWriter(authInfoWriter runtime.ClientAuthInfoWriter)

SetAuthInfoWriter adds the authInfoWriter to the old create policy params

func (*OldCreatePolicyParams) SetBody added in v0.84.0

SetBody adds the body to the old create policy params

func (*OldCreatePolicyParams) SetContext added in v0.84.0

func (o *OldCreatePolicyParams) SetContext(ctx context.Context)

SetContext adds the context to the old create policy params

func (*OldCreatePolicyParams) SetFlightId added in v0.84.0

func (o *OldCreatePolicyParams) SetFlightId(flightId string)

SetFlightId adds the flightId as the header value for this specific endpoint

func (*OldCreatePolicyParams) SetHTTPClient added in v0.84.0

func (o *OldCreatePolicyParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the old create policy params

func (*OldCreatePolicyParams) SetHTTPClientTransport added in v0.84.0

func (o *OldCreatePolicyParams) SetHTTPClientTransport(roundTripper http.RoundTripper)

SetHTTPClient adds the HTTPClient Transport to the old create policy params

func (*OldCreatePolicyParams) SetTimeout added in v0.84.0

func (o *OldCreatePolicyParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the old create policy params

func (*OldCreatePolicyParams) WithBody added in v0.84.0

WithBody adds the body to the old create policy params

func (*OldCreatePolicyParams) WithContext added in v0.84.0

WithContext adds the context to the old create policy params

func (*OldCreatePolicyParams) WithHTTPClient added in v0.84.0

func (o *OldCreatePolicyParams) WithHTTPClient(client *http.Client) *OldCreatePolicyParams

WithHTTPClient adds the HTTPClient to the old create policy params

func (*OldCreatePolicyParams) WithTimeout added in v0.84.0

func (o *OldCreatePolicyParams) WithTimeout(timeout time.Duration) *OldCreatePolicyParams

WithTimeout adds the timeout to the old create policy params

func (*OldCreatePolicyParams) WriteToRequest added in v0.84.0

func (o *OldCreatePolicyParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error

WriteToRequest writes these params to a swagger request

type OldCreatePolicyReader added in v0.84.0

type OldCreatePolicyReader struct {
	// contains filtered or unexported fields
}

OldCreatePolicyReader is a Reader for the OldCreatePolicy structure.

func (*OldCreatePolicyReader) ReadResponse added in v0.84.0

func (o *OldCreatePolicyReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type OldCreatePolicyUnprocessableEntity added in v0.84.0

type OldCreatePolicyUnprocessableEntity struct {
	Payload *legalclientmodels.ValidationErrorEntity
}

OldCreatePolicyUnprocessableEntity handles this case with default header values.

<table><tr><td>ErrorCode</td><td>ErrorMessage</td></tr><tr><td>20002</td><td>validation error</td></tr></table>

func NewOldCreatePolicyUnprocessableEntity added in v0.84.0

func NewOldCreatePolicyUnprocessableEntity() *OldCreatePolicyUnprocessableEntity

NewOldCreatePolicyUnprocessableEntity creates a OldCreatePolicyUnprocessableEntity with default headers values

func (*OldCreatePolicyUnprocessableEntity) Error added in v0.84.0

func (*OldCreatePolicyUnprocessableEntity) GetPayload added in v0.84.0

func (*OldCreatePolicyUnprocessableEntity) ToJSONString added in v0.84.0

func (o *OldCreatePolicyUnprocessableEntity) ToJSONString() string

type OldPartialUpdatePolicyBadRequest added in v0.84.0

type OldPartialUpdatePolicyBadRequest struct {
	Payload *legalclientmodels.ErrorEntity
}

OldPartialUpdatePolicyBadRequest handles this case with default header values.

<table><tr><td>NumericErrorCode</td><td>ErrorCode</td></tr><tr><td>40032</td><td>errors.net.accelbyte.platform.legal.invalid_base_policy</td></tr><tr><td>40038</td><td>errors.net.accelbyte.platform.legal.invalid_affected_client_id</td></tr></table>

func NewOldPartialUpdatePolicyBadRequest added in v0.84.0

func NewOldPartialUpdatePolicyBadRequest() *OldPartialUpdatePolicyBadRequest

NewOldPartialUpdatePolicyBadRequest creates a OldPartialUpdatePolicyBadRequest with default headers values

func (*OldPartialUpdatePolicyBadRequest) Error added in v0.84.0

func (*OldPartialUpdatePolicyBadRequest) GetPayload added in v0.84.0

func (*OldPartialUpdatePolicyBadRequest) ToJSONString added in v0.84.0

func (o *OldPartialUpdatePolicyBadRequest) ToJSONString() string

type OldPartialUpdatePolicyNotFound added in v0.84.0

type OldPartialUpdatePolicyNotFound struct {
	Payload *legalclientmodels.ErrorEntity
}

OldPartialUpdatePolicyNotFound handles this case with default header values.

<table><tr><td>NumericErrorCode</td><td>ErrorCode</td></tr><tr><td>40030</td><td>errors.net.accelbyte.platform.legal.policy_type_not_exist</td></tr></table>

func NewOldPartialUpdatePolicyNotFound added in v0.84.0

func NewOldPartialUpdatePolicyNotFound() *OldPartialUpdatePolicyNotFound

NewOldPartialUpdatePolicyNotFound creates a OldPartialUpdatePolicyNotFound with default headers values

func (*OldPartialUpdatePolicyNotFound) Error added in v0.84.0

func (*OldPartialUpdatePolicyNotFound) GetPayload added in v0.84.0

func (*OldPartialUpdatePolicyNotFound) ToJSONString added in v0.84.0

func (o *OldPartialUpdatePolicyNotFound) ToJSONString() string

type OldPartialUpdatePolicyOK added in v0.84.0

type OldPartialUpdatePolicyOK struct {
	Payload *legalclientmodels.UpdateBasePolicyResponse
}

OldPartialUpdatePolicyOK handles this case with default header values.

successful operation

func NewOldPartialUpdatePolicyOK added in v0.84.0

func NewOldPartialUpdatePolicyOK() *OldPartialUpdatePolicyOK

NewOldPartialUpdatePolicyOK creates a OldPartialUpdatePolicyOK with default headers values

func (*OldPartialUpdatePolicyOK) Error added in v0.84.0

func (o *OldPartialUpdatePolicyOK) Error() string

func (*OldPartialUpdatePolicyOK) GetPayload added in v0.84.0

func (*OldPartialUpdatePolicyOK) ToJSONString added in v0.84.0

func (o *OldPartialUpdatePolicyOK) ToJSONString() string

type OldPartialUpdatePolicyParams added in v0.84.0

type OldPartialUpdatePolicyParams struct {

	/*RetryPolicy*/
	RetryPolicy *utils.Retry
	/*Body*/
	Body *legalclientmodels.UpdateBasePolicyRequest
	/*BasePolicyID
	  BasePolicy Id

	*/
	BasePolicyID string

	AuthInfoWriter runtime.ClientAuthInfoWriter
	Context        context.Context
	HTTPClient     *http.Client

	// XFlightId is an optional parameter from this SDK
	XFlightId *string
	// contains filtered or unexported fields
}

OldPartialUpdatePolicyParams contains all the parameters to send to the API endpoint for the old partial update policy operation typically these are written to a http.Request

func NewOldPartialUpdatePolicyParams added in v0.84.0

func NewOldPartialUpdatePolicyParams() *OldPartialUpdatePolicyParams

NewOldPartialUpdatePolicyParams creates a new OldPartialUpdatePolicyParams object with the default values initialized.

func NewOldPartialUpdatePolicyParamsWithContext added in v0.84.0

func NewOldPartialUpdatePolicyParamsWithContext(ctx context.Context) *OldPartialUpdatePolicyParams

NewOldPartialUpdatePolicyParamsWithContext creates a new OldPartialUpdatePolicyParams object with the default values initialized, and the ability to set a context for a request

func NewOldPartialUpdatePolicyParamsWithHTTPClient added in v0.84.0

func NewOldPartialUpdatePolicyParamsWithHTTPClient(client *http.Client) *OldPartialUpdatePolicyParams

NewOldPartialUpdatePolicyParamsWithHTTPClient creates a new OldPartialUpdatePolicyParams object with the default values initialized, and the ability to set a custom HTTPClient for a request

func NewOldPartialUpdatePolicyParamsWithTimeout added in v0.84.0

func NewOldPartialUpdatePolicyParamsWithTimeout(timeout time.Duration) *OldPartialUpdatePolicyParams

NewOldPartialUpdatePolicyParamsWithTimeout creates a new OldPartialUpdatePolicyParams object with the default values initialized, and the ability to set a timeout on a request

func (*OldPartialUpdatePolicyParams) SetAuthInfoWriter added in v0.84.0

func (o *OldPartialUpdatePolicyParams) SetAuthInfoWriter(authInfoWriter runtime.ClientAuthInfoWriter)

SetAuthInfoWriter adds the authInfoWriter to the old partial update policy params

func (*OldPartialUpdatePolicyParams) SetBasePolicyID added in v0.84.0

func (o *OldPartialUpdatePolicyParams) SetBasePolicyID(basePolicyID string)

SetBasePolicyID adds the basePolicyId to the old partial update policy params

func (*OldPartialUpdatePolicyParams) SetBody added in v0.84.0

SetBody adds the body to the old partial update policy params

func (*OldPartialUpdatePolicyParams) SetContext added in v0.84.0

func (o *OldPartialUpdatePolicyParams) SetContext(ctx context.Context)

SetContext adds the context to the old partial update policy params

func (*OldPartialUpdatePolicyParams) SetFlightId added in v0.84.0

func (o *OldPartialUpdatePolicyParams) SetFlightId(flightId string)

SetFlightId adds the flightId as the header value for this specific endpoint

func (*OldPartialUpdatePolicyParams) SetHTTPClient added in v0.84.0

func (o *OldPartialUpdatePolicyParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the old partial update policy params

func (*OldPartialUpdatePolicyParams) SetHTTPClientTransport added in v0.84.0

func (o *OldPartialUpdatePolicyParams) SetHTTPClientTransport(roundTripper http.RoundTripper)

SetHTTPClient adds the HTTPClient Transport to the old partial update policy params

func (*OldPartialUpdatePolicyParams) SetTimeout added in v0.84.0

func (o *OldPartialUpdatePolicyParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the old partial update policy params

func (*OldPartialUpdatePolicyParams) WithBasePolicyID added in v0.84.0

func (o *OldPartialUpdatePolicyParams) WithBasePolicyID(basePolicyID string) *OldPartialUpdatePolicyParams

WithBasePolicyID adds the basePolicyID to the old partial update policy params

func (*OldPartialUpdatePolicyParams) WithBody added in v0.84.0

WithBody adds the body to the old partial update policy params

func (*OldPartialUpdatePolicyParams) WithContext added in v0.84.0

WithContext adds the context to the old partial update policy params

func (*OldPartialUpdatePolicyParams) WithHTTPClient added in v0.84.0

WithHTTPClient adds the HTTPClient to the old partial update policy params

func (*OldPartialUpdatePolicyParams) WithTimeout added in v0.84.0

WithTimeout adds the timeout to the old partial update policy params

func (*OldPartialUpdatePolicyParams) WriteToRequest added in v0.84.0

WriteToRequest writes these params to a swagger request

type OldPartialUpdatePolicyReader added in v0.84.0

type OldPartialUpdatePolicyReader struct {
	// contains filtered or unexported fields
}

OldPartialUpdatePolicyReader is a Reader for the OldPartialUpdatePolicy structure.

func (*OldPartialUpdatePolicyReader) ReadResponse added in v0.84.0

func (o *OldPartialUpdatePolicyReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type OldRetrieveAllPolicyTypesOK added in v0.84.0

type OldRetrieveAllPolicyTypesOK struct {
	Payload []*legalclientmodels.RetrievePolicyTypeResponse
}

OldRetrieveAllPolicyTypesOK handles this case with default header values.

successful operation

func NewOldRetrieveAllPolicyTypesOK added in v0.84.0

func NewOldRetrieveAllPolicyTypesOK() *OldRetrieveAllPolicyTypesOK

NewOldRetrieveAllPolicyTypesOK creates a OldRetrieveAllPolicyTypesOK with default headers values

func (*OldRetrieveAllPolicyTypesOK) Error added in v0.84.0

func (*OldRetrieveAllPolicyTypesOK) GetPayload added in v0.84.0

func (*OldRetrieveAllPolicyTypesOK) ToJSONString added in v0.84.0

func (o *OldRetrieveAllPolicyTypesOK) ToJSONString() string

type OldRetrieveAllPolicyTypesParams added in v0.84.0

type OldRetrieveAllPolicyTypesParams struct {

	/*RetryPolicy*/
	RetryPolicy *utils.Retry
	/*Offset
	  Offset

	*/
	Offset *int32
	/*Limit
	  Limit

	*/
	Limit int32

	AuthInfoWriter runtime.ClientAuthInfoWriter
	Context        context.Context
	HTTPClient     *http.Client

	// XFlightId is an optional parameter from this SDK
	XFlightId *string
	// contains filtered or unexported fields
}

OldRetrieveAllPolicyTypesParams contains all the parameters to send to the API endpoint for the old retrieve all policy types operation typically these are written to a http.Request

func NewOldRetrieveAllPolicyTypesParams added in v0.84.0

func NewOldRetrieveAllPolicyTypesParams() *OldRetrieveAllPolicyTypesParams

NewOldRetrieveAllPolicyTypesParams creates a new OldRetrieveAllPolicyTypesParams object with the default values initialized.

func NewOldRetrieveAllPolicyTypesParamsWithContext added in v0.84.0

func NewOldRetrieveAllPolicyTypesParamsWithContext(ctx context.Context) *OldRetrieveAllPolicyTypesParams

NewOldRetrieveAllPolicyTypesParamsWithContext creates a new OldRetrieveAllPolicyTypesParams object with the default values initialized, and the ability to set a context for a request

func NewOldRetrieveAllPolicyTypesParamsWithHTTPClient added in v0.84.0

func NewOldRetrieveAllPolicyTypesParamsWithHTTPClient(client *http.Client) *OldRetrieveAllPolicyTypesParams

NewOldRetrieveAllPolicyTypesParamsWithHTTPClient creates a new OldRetrieveAllPolicyTypesParams object with the default values initialized, and the ability to set a custom HTTPClient for a request

func NewOldRetrieveAllPolicyTypesParamsWithTimeout added in v0.84.0

func NewOldRetrieveAllPolicyTypesParamsWithTimeout(timeout time.Duration) *OldRetrieveAllPolicyTypesParams

NewOldRetrieveAllPolicyTypesParamsWithTimeout creates a new OldRetrieveAllPolicyTypesParams object with the default values initialized, and the ability to set a timeout on a request

func (*OldRetrieveAllPolicyTypesParams) SetAuthInfoWriter added in v0.84.0

func (o *OldRetrieveAllPolicyTypesParams) SetAuthInfoWriter(authInfoWriter runtime.ClientAuthInfoWriter)

SetAuthInfoWriter adds the authInfoWriter to the old retrieve all policy types params

func (*OldRetrieveAllPolicyTypesParams) SetContext added in v0.84.0

func (o *OldRetrieveAllPolicyTypesParams) SetContext(ctx context.Context)

SetContext adds the context to the old retrieve all policy types params

func (*OldRetrieveAllPolicyTypesParams) SetFlightId added in v0.84.0

func (o *OldRetrieveAllPolicyTypesParams) SetFlightId(flightId string)

SetFlightId adds the flightId as the header value for this specific endpoint

func (*OldRetrieveAllPolicyTypesParams) SetHTTPClient added in v0.84.0

func (o *OldRetrieveAllPolicyTypesParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the old retrieve all policy types params

func (*OldRetrieveAllPolicyTypesParams) SetHTTPClientTransport added in v0.84.0

func (o *OldRetrieveAllPolicyTypesParams) SetHTTPClientTransport(roundTripper http.RoundTripper)

SetHTTPClient adds the HTTPClient Transport to the old retrieve all policy types params

func (*OldRetrieveAllPolicyTypesParams) SetLimit added in v0.84.0

func (o *OldRetrieveAllPolicyTypesParams) SetLimit(limit int32)

SetLimit adds the limit to the old retrieve all policy types params

func (*OldRetrieveAllPolicyTypesParams) SetOffset added in v0.84.0

func (o *OldRetrieveAllPolicyTypesParams) SetOffset(offset *int32)

SetOffset adds the offset to the old retrieve all policy types params

func (*OldRetrieveAllPolicyTypesParams) SetTimeout added in v0.84.0

func (o *OldRetrieveAllPolicyTypesParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the old retrieve all policy types params

func (*OldRetrieveAllPolicyTypesParams) WithContext added in v0.84.0

WithContext adds the context to the old retrieve all policy types params

func (*OldRetrieveAllPolicyTypesParams) WithHTTPClient added in v0.84.0

WithHTTPClient adds the HTTPClient to the old retrieve all policy types params

func (*OldRetrieveAllPolicyTypesParams) WithLimit added in v0.84.0

WithLimit adds the limit to the old retrieve all policy types params

func (*OldRetrieveAllPolicyTypesParams) WithOffset added in v0.84.0

WithOffset adds the offset to the old retrieve all policy types params

func (*OldRetrieveAllPolicyTypesParams) WithTimeout added in v0.84.0

WithTimeout adds the timeout to the old retrieve all policy types params

func (*OldRetrieveAllPolicyTypesParams) WriteToRequest added in v0.84.0

WriteToRequest writes these params to a swagger request

type OldRetrieveAllPolicyTypesReader added in v0.84.0

type OldRetrieveAllPolicyTypesReader struct {
	// contains filtered or unexported fields
}

OldRetrieveAllPolicyTypesReader is a Reader for the OldRetrieveAllPolicyTypes structure.

func (*OldRetrieveAllPolicyTypesReader) ReadResponse added in v0.84.0

func (o *OldRetrieveAllPolicyTypesReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type OldRetrievePolicyCountryNotFound added in v0.84.0

type OldRetrievePolicyCountryNotFound struct {
	Payload *legalclientmodels.ErrorEntity
}

OldRetrievePolicyCountryNotFound handles this case with default header values.

<table><tr><td>NumericErrorCode</td><td>ErrorCode</td></tr><tr><td>40041</td><td>errors.net.accelbyte.platform.legal.policy_not_found</td></tr></table>

func NewOldRetrievePolicyCountryNotFound added in v0.84.0

func NewOldRetrievePolicyCountryNotFound() *OldRetrievePolicyCountryNotFound

NewOldRetrievePolicyCountryNotFound creates a OldRetrievePolicyCountryNotFound with default headers values

func (*OldRetrievePolicyCountryNotFound) Error added in v0.84.0

func (*OldRetrievePolicyCountryNotFound) GetPayload added in v0.84.0

func (*OldRetrievePolicyCountryNotFound) ToJSONString added in v0.84.0

func (o *OldRetrievePolicyCountryNotFound) ToJSONString() string

type OldRetrievePolicyCountryOK added in v0.84.0

type OldRetrievePolicyCountryOK struct {
	Payload *legalclientmodels.RetrievePolicyResponse
}

OldRetrievePolicyCountryOK handles this case with default header values.

successful operation

func NewOldRetrievePolicyCountryOK added in v0.84.0

func NewOldRetrievePolicyCountryOK() *OldRetrievePolicyCountryOK

NewOldRetrievePolicyCountryOK creates a OldRetrievePolicyCountryOK with default headers values

func (*OldRetrievePolicyCountryOK) Error added in v0.84.0

func (*OldRetrievePolicyCountryOK) GetPayload added in v0.84.0

func (*OldRetrievePolicyCountryOK) ToJSONString added in v0.84.0

func (o *OldRetrievePolicyCountryOK) ToJSONString() string

type OldRetrievePolicyCountryParams added in v0.84.0

type OldRetrievePolicyCountryParams struct {

	/*RetryPolicy*/
	RetryPolicy *utils.Retry
	/*BasePolicyID
	  BasePolicy Id

	*/
	BasePolicyID string
	/*CountryCode
	  Country Code

	*/
	CountryCode string

	AuthInfoWriter runtime.ClientAuthInfoWriter
	Context        context.Context
	HTTPClient     *http.Client

	// XFlightId is an optional parameter from this SDK
	XFlightId *string
	// contains filtered or unexported fields
}

OldRetrievePolicyCountryParams contains all the parameters to send to the API endpoint for the old retrieve policy country operation typically these are written to a http.Request

func NewOldRetrievePolicyCountryParams added in v0.84.0

func NewOldRetrievePolicyCountryParams() *OldRetrievePolicyCountryParams

NewOldRetrievePolicyCountryParams creates a new OldRetrievePolicyCountryParams object with the default values initialized.

func NewOldRetrievePolicyCountryParamsWithContext added in v0.84.0

func NewOldRetrievePolicyCountryParamsWithContext(ctx context.Context) *OldRetrievePolicyCountryParams

NewOldRetrievePolicyCountryParamsWithContext creates a new OldRetrievePolicyCountryParams object with the default values initialized, and the ability to set a context for a request

func NewOldRetrievePolicyCountryParamsWithHTTPClient added in v0.84.0

func NewOldRetrievePolicyCountryParamsWithHTTPClient(client *http.Client) *OldRetrievePolicyCountryParams

NewOldRetrievePolicyCountryParamsWithHTTPClient creates a new OldRetrievePolicyCountryParams object with the default values initialized, and the ability to set a custom HTTPClient for a request

func NewOldRetrievePolicyCountryParamsWithTimeout added in v0.84.0

func NewOldRetrievePolicyCountryParamsWithTimeout(timeout time.Duration) *OldRetrievePolicyCountryParams

NewOldRetrievePolicyCountryParamsWithTimeout creates a new OldRetrievePolicyCountryParams object with the default values initialized, and the ability to set a timeout on a request

func (*OldRetrievePolicyCountryParams) SetAuthInfoWriter added in v0.84.0

func (o *OldRetrievePolicyCountryParams) SetAuthInfoWriter(authInfoWriter runtime.ClientAuthInfoWriter)

SetAuthInfoWriter adds the authInfoWriter to the old retrieve policy country params

func (*OldRetrievePolicyCountryParams) SetBasePolicyID added in v0.84.0

func (o *OldRetrievePolicyCountryParams) SetBasePolicyID(basePolicyID string)

SetBasePolicyID adds the basePolicyId to the old retrieve policy country params

func (*OldRetrievePolicyCountryParams) SetContext added in v0.84.0

func (o *OldRetrievePolicyCountryParams) SetContext(ctx context.Context)

SetContext adds the context to the old retrieve policy country params

func (*OldRetrievePolicyCountryParams) SetCountryCode added in v0.84.0

func (o *OldRetrievePolicyCountryParams) SetCountryCode(countryCode string)

SetCountryCode adds the countryCode to the old retrieve policy country params

func (*OldRetrievePolicyCountryParams) SetFlightId added in v0.84.0

func (o *OldRetrievePolicyCountryParams) SetFlightId(flightId string)

SetFlightId adds the flightId as the header value for this specific endpoint

func (*OldRetrievePolicyCountryParams) SetHTTPClient added in v0.84.0

func (o *OldRetrievePolicyCountryParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the old retrieve policy country params

func (*OldRetrievePolicyCountryParams) SetHTTPClientTransport added in v0.84.0

func (o *OldRetrievePolicyCountryParams) SetHTTPClientTransport(roundTripper http.RoundTripper)

SetHTTPClient adds the HTTPClient Transport to the old retrieve policy country params

func (*OldRetrievePolicyCountryParams) SetTimeout added in v0.84.0

func (o *OldRetrievePolicyCountryParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the old retrieve policy country params

func (*OldRetrievePolicyCountryParams) WithBasePolicyID added in v0.84.0

func (o *OldRetrievePolicyCountryParams) WithBasePolicyID(basePolicyID string) *OldRetrievePolicyCountryParams

WithBasePolicyID adds the basePolicyID to the old retrieve policy country params

func (*OldRetrievePolicyCountryParams) WithContext added in v0.84.0

WithContext adds the context to the old retrieve policy country params

func (*OldRetrievePolicyCountryParams) WithCountryCode added in v0.84.0

func (o *OldRetrievePolicyCountryParams) WithCountryCode(countryCode string) *OldRetrievePolicyCountryParams

WithCountryCode adds the countryCode to the old retrieve policy country params

func (*OldRetrievePolicyCountryParams) WithHTTPClient added in v0.84.0

WithHTTPClient adds the HTTPClient to the old retrieve policy country params

func (*OldRetrievePolicyCountryParams) WithTimeout added in v0.84.0

WithTimeout adds the timeout to the old retrieve policy country params

func (*OldRetrievePolicyCountryParams) WriteToRequest added in v0.84.0

WriteToRequest writes these params to a swagger request

type OldRetrievePolicyCountryReader added in v0.84.0

type OldRetrievePolicyCountryReader struct {
	// contains filtered or unexported fields
}

OldRetrievePolicyCountryReader is a Reader for the OldRetrievePolicyCountry structure.

func (*OldRetrievePolicyCountryReader) ReadResponse added in v0.84.0

func (o *OldRetrievePolicyCountryReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type OldRetrieveSinglePolicyNotFound added in v0.84.0

type OldRetrieveSinglePolicyNotFound struct {
	Payload *legalclientmodels.ErrorEntity
}

OldRetrieveSinglePolicyNotFound handles this case with default header values.

<table><tr><td>NumericErrorCode</td><td>ErrorCode</td></tr><tr><td>40031</td><td>errors.net.accelbyte.platform.legal.base_policy_not_found</td></tr></table>

func NewOldRetrieveSinglePolicyNotFound added in v0.84.0

func NewOldRetrieveSinglePolicyNotFound() *OldRetrieveSinglePolicyNotFound

NewOldRetrieveSinglePolicyNotFound creates a OldRetrieveSinglePolicyNotFound with default headers values

func (*OldRetrieveSinglePolicyNotFound) Error added in v0.84.0

func (*OldRetrieveSinglePolicyNotFound) GetPayload added in v0.84.0

func (*OldRetrieveSinglePolicyNotFound) ToJSONString added in v0.84.0

func (o *OldRetrieveSinglePolicyNotFound) ToJSONString() string

type OldRetrieveSinglePolicyOK added in v0.84.0

type OldRetrieveSinglePolicyOK struct {
	Payload *legalclientmodels.RetrieveBasePolicyResponse
}

OldRetrieveSinglePolicyOK handles this case with default header values.

successful operation

func NewOldRetrieveSinglePolicyOK added in v0.84.0

func NewOldRetrieveSinglePolicyOK() *OldRetrieveSinglePolicyOK

NewOldRetrieveSinglePolicyOK creates a OldRetrieveSinglePolicyOK with default headers values

func (*OldRetrieveSinglePolicyOK) Error added in v0.84.0

func (o *OldRetrieveSinglePolicyOK) Error() string

func (*OldRetrieveSinglePolicyOK) GetPayload added in v0.84.0

func (*OldRetrieveSinglePolicyOK) ToJSONString added in v0.84.0

func (o *OldRetrieveSinglePolicyOK) ToJSONString() string

type OldRetrieveSinglePolicyParams added in v0.84.0

type OldRetrieveSinglePolicyParams struct {

	/*RetryPolicy*/
	RetryPolicy *utils.Retry
	/*BasePolicyID
	  BasePolicy Id

	*/
	BasePolicyID string

	AuthInfoWriter runtime.ClientAuthInfoWriter
	Context        context.Context
	HTTPClient     *http.Client

	// XFlightId is an optional parameter from this SDK
	XFlightId *string
	// contains filtered or unexported fields
}

OldRetrieveSinglePolicyParams contains all the parameters to send to the API endpoint for the old retrieve single policy operation typically these are written to a http.Request

func NewOldRetrieveSinglePolicyParams added in v0.84.0

func NewOldRetrieveSinglePolicyParams() *OldRetrieveSinglePolicyParams

NewOldRetrieveSinglePolicyParams creates a new OldRetrieveSinglePolicyParams object with the default values initialized.

func NewOldRetrieveSinglePolicyParamsWithContext added in v0.84.0

func NewOldRetrieveSinglePolicyParamsWithContext(ctx context.Context) *OldRetrieveSinglePolicyParams

NewOldRetrieveSinglePolicyParamsWithContext creates a new OldRetrieveSinglePolicyParams object with the default values initialized, and the ability to set a context for a request

func NewOldRetrieveSinglePolicyParamsWithHTTPClient added in v0.84.0

func NewOldRetrieveSinglePolicyParamsWithHTTPClient(client *http.Client) *OldRetrieveSinglePolicyParams

NewOldRetrieveSinglePolicyParamsWithHTTPClient creates a new OldRetrieveSinglePolicyParams object with the default values initialized, and the ability to set a custom HTTPClient for a request

func NewOldRetrieveSinglePolicyParamsWithTimeout added in v0.84.0

func NewOldRetrieveSinglePolicyParamsWithTimeout(timeout time.Duration) *OldRetrieveSinglePolicyParams

NewOldRetrieveSinglePolicyParamsWithTimeout creates a new OldRetrieveSinglePolicyParams object with the default values initialized, and the ability to set a timeout on a request

func (*OldRetrieveSinglePolicyParams) SetAuthInfoWriter added in v0.84.0

func (o *OldRetrieveSinglePolicyParams) SetAuthInfoWriter(authInfoWriter runtime.ClientAuthInfoWriter)

SetAuthInfoWriter adds the authInfoWriter to the old retrieve single policy params

func (*OldRetrieveSinglePolicyParams) SetBasePolicyID added in v0.84.0

func (o *OldRetrieveSinglePolicyParams) SetBasePolicyID(basePolicyID string)

SetBasePolicyID adds the basePolicyId to the old retrieve single policy params

func (*OldRetrieveSinglePolicyParams) SetContext added in v0.84.0

func (o *OldRetrieveSinglePolicyParams) SetContext(ctx context.Context)

SetContext adds the context to the old retrieve single policy params

func (*OldRetrieveSinglePolicyParams) SetFlightId added in v0.84.0

func (o *OldRetrieveSinglePolicyParams) SetFlightId(flightId string)

SetFlightId adds the flightId as the header value for this specific endpoint

func (*OldRetrieveSinglePolicyParams) SetHTTPClient added in v0.84.0

func (o *OldRetrieveSinglePolicyParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the old retrieve single policy params

func (*OldRetrieveSinglePolicyParams) SetHTTPClientTransport added in v0.84.0

func (o *OldRetrieveSinglePolicyParams) SetHTTPClientTransport(roundTripper http.RoundTripper)

SetHTTPClient adds the HTTPClient Transport to the old retrieve single policy params

func (*OldRetrieveSinglePolicyParams) SetTimeout added in v0.84.0

func (o *OldRetrieveSinglePolicyParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the old retrieve single policy params

func (*OldRetrieveSinglePolicyParams) WithBasePolicyID added in v0.84.0

func (o *OldRetrieveSinglePolicyParams) WithBasePolicyID(basePolicyID string) *OldRetrieveSinglePolicyParams

WithBasePolicyID adds the basePolicyID to the old retrieve single policy params

func (*OldRetrieveSinglePolicyParams) WithContext added in v0.84.0

WithContext adds the context to the old retrieve single policy params

func (*OldRetrieveSinglePolicyParams) WithHTTPClient added in v0.84.0

WithHTTPClient adds the HTTPClient to the old retrieve single policy params

func (*OldRetrieveSinglePolicyParams) WithTimeout added in v0.84.0

WithTimeout adds the timeout to the old retrieve single policy params

func (*OldRetrieveSinglePolicyParams) WriteToRequest added in v0.84.0

WriteToRequest writes these params to a swagger request

type OldRetrieveSinglePolicyReader added in v0.84.0

type OldRetrieveSinglePolicyReader struct {
	// contains filtered or unexported fields
}

OldRetrieveSinglePolicyReader is a Reader for the OldRetrieveSinglePolicy structure.

func (*OldRetrieveSinglePolicyReader) ReadResponse added in v0.84.0

func (o *OldRetrieveSinglePolicyReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type RetrieveAllLegalPoliciesOK

type RetrieveAllLegalPoliciesOK struct {
	Payload []*legalclientmodels.RetrieveBasePolicyResponse
}

RetrieveAllLegalPoliciesOK handles this case with default header values.

successful operation

func NewRetrieveAllLegalPoliciesOK

func NewRetrieveAllLegalPoliciesOK() *RetrieveAllLegalPoliciesOK

NewRetrieveAllLegalPoliciesOK creates a RetrieveAllLegalPoliciesOK with default headers values

func (*RetrieveAllLegalPoliciesOK) Error

func (*RetrieveAllLegalPoliciesOK) GetPayload

func (*RetrieveAllLegalPoliciesOK) ToJSONString added in v0.25.0

func (o *RetrieveAllLegalPoliciesOK) ToJSONString() string

type RetrieveAllLegalPoliciesParams

type RetrieveAllLegalPoliciesParams struct {

	/*RetryPolicy*/
	RetryPolicy *utils.Retry
	/*VisibleOnly*/
	VisibleOnly *bool

	AuthInfoWriter runtime.ClientAuthInfoWriter
	Context        context.Context
	HTTPClient     *http.Client

	// XFlightId is an optional parameter from this SDK
	XFlightId *string
	// contains filtered or unexported fields
}

RetrieveAllLegalPoliciesParams contains all the parameters to send to the API endpoint for the retrieve all legal policies operation typically these are written to a http.Request

func NewRetrieveAllLegalPoliciesParams

func NewRetrieveAllLegalPoliciesParams() *RetrieveAllLegalPoliciesParams

NewRetrieveAllLegalPoliciesParams creates a new RetrieveAllLegalPoliciesParams object with the default values initialized.

func NewRetrieveAllLegalPoliciesParamsWithContext

func NewRetrieveAllLegalPoliciesParamsWithContext(ctx context.Context) *RetrieveAllLegalPoliciesParams

NewRetrieveAllLegalPoliciesParamsWithContext creates a new RetrieveAllLegalPoliciesParams object with the default values initialized, and the ability to set a context for a request

func NewRetrieveAllLegalPoliciesParamsWithHTTPClient

func NewRetrieveAllLegalPoliciesParamsWithHTTPClient(client *http.Client) *RetrieveAllLegalPoliciesParams

NewRetrieveAllLegalPoliciesParamsWithHTTPClient creates a new RetrieveAllLegalPoliciesParams object with the default values initialized, and the ability to set a custom HTTPClient for a request

func NewRetrieveAllLegalPoliciesParamsWithTimeout

func NewRetrieveAllLegalPoliciesParamsWithTimeout(timeout time.Duration) *RetrieveAllLegalPoliciesParams

NewRetrieveAllLegalPoliciesParamsWithTimeout creates a new RetrieveAllLegalPoliciesParams object with the default values initialized, and the ability to set a timeout on a request

func (*RetrieveAllLegalPoliciesParams) SetAuthInfoWriter added in v0.17.0

func (o *RetrieveAllLegalPoliciesParams) SetAuthInfoWriter(authInfoWriter runtime.ClientAuthInfoWriter)

SetAuthInfoWriter adds the authInfoWriter to the retrieve all legal policies params

func (*RetrieveAllLegalPoliciesParams) SetContext

func (o *RetrieveAllLegalPoliciesParams) SetContext(ctx context.Context)

SetContext adds the context to the retrieve all legal policies params

func (*RetrieveAllLegalPoliciesParams) SetFlightId added in v0.63.0

func (o *RetrieveAllLegalPoliciesParams) SetFlightId(flightId string)

SetFlightId adds the flightId as the header value for this specific endpoint

func (*RetrieveAllLegalPoliciesParams) SetHTTPClient

func (o *RetrieveAllLegalPoliciesParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the retrieve all legal policies params

func (*RetrieveAllLegalPoliciesParams) SetHTTPClientTransport added in v0.19.0

func (o *RetrieveAllLegalPoliciesParams) SetHTTPClientTransport(roundTripper http.RoundTripper)

SetHTTPClient adds the HTTPClient Transport to the retrieve all legal policies params

func (*RetrieveAllLegalPoliciesParams) SetTimeout

func (o *RetrieveAllLegalPoliciesParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the retrieve all legal policies params

func (*RetrieveAllLegalPoliciesParams) SetVisibleOnly added in v0.70.0

func (o *RetrieveAllLegalPoliciesParams) SetVisibleOnly(visibleOnly *bool)

SetVisibleOnly adds the visibleOnly to the retrieve all legal policies params

func (*RetrieveAllLegalPoliciesParams) WithContext

WithContext adds the context to the retrieve all legal policies params

func (*RetrieveAllLegalPoliciesParams) WithHTTPClient

WithHTTPClient adds the HTTPClient to the retrieve all legal policies params

func (*RetrieveAllLegalPoliciesParams) WithTimeout

WithTimeout adds the timeout to the retrieve all legal policies params

func (*RetrieveAllLegalPoliciesParams) WithVisibleOnly added in v0.70.0

func (o *RetrieveAllLegalPoliciesParams) WithVisibleOnly(visibleOnly *bool) *RetrieveAllLegalPoliciesParams

WithVisibleOnly adds the visibleOnly to the retrieve all legal policies params

func (*RetrieveAllLegalPoliciesParams) WriteToRequest

WriteToRequest writes these params to a swagger request

type RetrieveAllLegalPoliciesReader

type RetrieveAllLegalPoliciesReader struct {
	// contains filtered or unexported fields
}

RetrieveAllLegalPoliciesReader is a Reader for the RetrieveAllLegalPolicies structure.

func (*RetrieveAllLegalPoliciesReader) ReadResponse

func (o *RetrieveAllLegalPoliciesReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

Jump to