policies_with_namespace_v2

package
v0.86.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 13, 2026 License: MIT Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client for policies with namespace v2 API

func (*Client) RetrieveLatestPoliciesByNamespaceAndCountryPublic deprecated added in v0.84.0

func (a *Client) RetrieveLatestPoliciesByNamespaceAndCountryPublic(params *RetrieveLatestPoliciesByNamespaceAndCountryPublicParams) (*RetrieveLatestPoliciesByNamespaceAndCountryPublicOK, error)

Deprecated: 2022-08-10 - Use RetrieveLatestPoliciesByNamespaceAndCountryPublicShort instead.

RetrieveLatestPoliciesByNamespaceAndCountryPublic retrieve latest policies by namespace and country This API is used to list all the related doc in register page, include optional & mandatory (when env config APP_LEGAL_AGREEMENT_ALWAYS_INCLUDE_DEFAULT=true). Other detail info: Here are the result of different cases

  • Document 1, Region US (default, mandatory), UA (optional); clientID: [client_A]
  • Document 2, Region US (default, optional), UA (mandatory); clientID: [client_A]
  • Document 3, Region UA (default, mandatory); clientID: [client_A]
  • Document 4, Region US (default, optional); clientID: [client_A]
  • Document 5, Region US (default, optional); clientID: [client_B]
  • Document 6, Region CA (mandatory, optional), UA (optional); clientID: [client_B]
  • Query by: Region UA + client_A
  • Response: Document 1 (UA, optional), Document 2 (UA, mandatory), Document 3 (UA, mandatory), Document 4 (US, optional)
  • Query by: Region CA + client_A
  • Response: Document 1 (US, mandatory), Document 2 (US, mandatory), Document 3 (UA, mandatory), Document 4 (US, optional)
  • Query by: Region UA + client_B
  • Response: Document 5 (US, optional), Document 6 (UA, optional)
  • Query by: Region CN + client_B
  • Response: Document 5 (US, optional), Document 6 (CA, mandatory)

Note: If APP_LEGAL_AGREEMENT_ALWAYS_INCLUDE_DEFAULT=false the behavior will be same with `/agreement/public/policies/namespaces/{namespace}/countries/{country_code}?defaultOnEmpty=true&visibleOnly;=true`;Here are the result of different cases

  • Query by: Region UA + client_A
  • Response: Document 1 (UA, optional), Document 2 (UA, mandatory), Document 3 (UA, mandatory)
  • Query by: Region UA + client_B
  • Response: Document 5 (US, optional)

func (*Client) RetrieveLatestPoliciesByNamespaceAndCountryPublicShort added in v0.84.0

func (a *Client) RetrieveLatestPoliciesByNamespaceAndCountryPublicShort(params *RetrieveLatestPoliciesByNamespaceAndCountryPublicParams) (*RetrieveLatestPoliciesByNamespaceAndCountryPublicOK, error)

RetrieveLatestPoliciesByNamespaceAndCountryPublicShort retrieve latest policies by namespace and country This API is used to list all the related doc in register page, include optional & mandatory (when env config APP_LEGAL_AGREEMENT_ALWAYS_INCLUDE_DEFAULT=true). Other detail info: Here are the result of different cases

  • Document 1, Region US (default, mandatory), UA (optional); clientID: [client_A]
  • Document 2, Region US (default, optional), UA (mandatory); clientID: [client_A]
  • Document 3, Region UA (default, mandatory); clientID: [client_A]
  • Document 4, Region US (default, optional); clientID: [client_A]
  • Document 5, Region US (default, optional); clientID: [client_B]
  • Document 6, Region CA (mandatory, optional), UA (optional); clientID: [client_B]
  • Query by: Region UA + client_A
  • Response: Document 1 (UA, optional), Document 2 (UA, mandatory), Document 3 (UA, mandatory), Document 4 (US, optional)
  • Query by: Region CA + client_A
  • Response: Document 1 (US, mandatory), Document 2 (US, mandatory), Document 3 (UA, mandatory), Document 4 (US, optional)
  • Query by: Region UA + client_B
  • Response: Document 5 (US, optional), Document 6 (UA, optional)
  • Query by: Region CN + client_B
  • Response: Document 5 (US, optional), Document 6 (CA, mandatory)

Note: If APP_LEGAL_AGREEMENT_ALWAYS_INCLUDE_DEFAULT=false the behavior will be same with `/agreement/public/policies/namespaces/{namespace}/countries/{country_code}?defaultOnEmpty=true&visibleOnly;=true`;Here are the result of different cases

  • Query by: Region UA + client_A
  • Response: Document 1 (UA, optional), Document 2 (UA, mandatory), Document 3 (UA, mandatory)
  • Query by: Region UA + client_B
  • Response: Document 5 (US, optional)

func (*Client) SetTransport

func (a *Client) SetTransport(transport runtime.ClientTransport)

SetTransport changes the transport on the client

type ClientService

type ClientService interface {
	RetrieveLatestPoliciesByNamespaceAndCountryPublic(params *RetrieveLatestPoliciesByNamespaceAndCountryPublicParams) (*RetrieveLatestPoliciesByNamespaceAndCountryPublicOK, error)
	RetrieveLatestPoliciesByNamespaceAndCountryPublicShort(params *RetrieveLatestPoliciesByNamespaceAndCountryPublicParams) (*RetrieveLatestPoliciesByNamespaceAndCountryPublicOK, error)

	SetTransport(transport runtime.ClientTransport)
}

ClientService is the interface for Client methods

func New

func New(transport runtime.ClientTransport, formats strfmt.Registry) ClientService

New creates a new policies with namespace v2 API client.

type RetrieveLatestPoliciesByNamespaceAndCountryPublicOK added in v0.84.0

type RetrieveLatestPoliciesByNamespaceAndCountryPublicOK struct {
	Payload []*legalclientmodels.RetrieveSimplePolicyPublicResponseV2
}

RetrieveLatestPoliciesByNamespaceAndCountryPublicOK handles this case with default header values.

successful operation

func NewRetrieveLatestPoliciesByNamespaceAndCountryPublicOK added in v0.84.0

func NewRetrieveLatestPoliciesByNamespaceAndCountryPublicOK() *RetrieveLatestPoliciesByNamespaceAndCountryPublicOK

NewRetrieveLatestPoliciesByNamespaceAndCountryPublicOK creates a RetrieveLatestPoliciesByNamespaceAndCountryPublicOK with default headers values

func (*RetrieveLatestPoliciesByNamespaceAndCountryPublicOK) Error added in v0.84.0

func (*RetrieveLatestPoliciesByNamespaceAndCountryPublicOK) GetPayload added in v0.84.0

func (*RetrieveLatestPoliciesByNamespaceAndCountryPublicOK) ToJSONString added in v0.84.0

type RetrieveLatestPoliciesByNamespaceAndCountryPublicParams added in v0.84.0

type RetrieveLatestPoliciesByNamespaceAndCountryPublicParams struct {

	/*RetryPolicy*/
	RetryPolicy *utils.Retry
	/*CountryCode
	  Country Code

	*/
	CountryCode string
	/*Namespace
	  Namespace

	*/
	Namespace string
	/*ClientID
	  clientId, which used to login

	*/
	ClientID string

	AuthInfoWriter runtime.ClientAuthInfoWriter
	Context        context.Context
	HTTPClient     *http.Client

	// XFlightId is an optional parameter from this SDK
	XFlightId *string
	// contains filtered or unexported fields
}

RetrieveLatestPoliciesByNamespaceAndCountryPublicParams contains all the parameters to send to the API endpoint for the retrieve latest policies by namespace and country public operation typically these are written to a http.Request

func NewRetrieveLatestPoliciesByNamespaceAndCountryPublicParams added in v0.84.0

func NewRetrieveLatestPoliciesByNamespaceAndCountryPublicParams() *RetrieveLatestPoliciesByNamespaceAndCountryPublicParams

NewRetrieveLatestPoliciesByNamespaceAndCountryPublicParams creates a new RetrieveLatestPoliciesByNamespaceAndCountryPublicParams object with the default values initialized.

func NewRetrieveLatestPoliciesByNamespaceAndCountryPublicParamsWithContext added in v0.84.0

func NewRetrieveLatestPoliciesByNamespaceAndCountryPublicParamsWithContext(ctx context.Context) *RetrieveLatestPoliciesByNamespaceAndCountryPublicParams

NewRetrieveLatestPoliciesByNamespaceAndCountryPublicParamsWithContext creates a new RetrieveLatestPoliciesByNamespaceAndCountryPublicParams object with the default values initialized, and the ability to set a context for a request

func NewRetrieveLatestPoliciesByNamespaceAndCountryPublicParamsWithHTTPClient added in v0.84.0

func NewRetrieveLatestPoliciesByNamespaceAndCountryPublicParamsWithHTTPClient(client *http.Client) *RetrieveLatestPoliciesByNamespaceAndCountryPublicParams

NewRetrieveLatestPoliciesByNamespaceAndCountryPublicParamsWithHTTPClient creates a new RetrieveLatestPoliciesByNamespaceAndCountryPublicParams object with the default values initialized, and the ability to set a custom HTTPClient for a request

func NewRetrieveLatestPoliciesByNamespaceAndCountryPublicParamsWithTimeout added in v0.84.0

func NewRetrieveLatestPoliciesByNamespaceAndCountryPublicParamsWithTimeout(timeout time.Duration) *RetrieveLatestPoliciesByNamespaceAndCountryPublicParams

NewRetrieveLatestPoliciesByNamespaceAndCountryPublicParamsWithTimeout creates a new RetrieveLatestPoliciesByNamespaceAndCountryPublicParams object with the default values initialized, and the ability to set a timeout on a request

func (*RetrieveLatestPoliciesByNamespaceAndCountryPublicParams) SetAuthInfoWriter added in v0.84.0

SetAuthInfoWriter adds the authInfoWriter to the retrieve latest policies by namespace and country public params

func (*RetrieveLatestPoliciesByNamespaceAndCountryPublicParams) SetClientID added in v0.84.0

SetClientID adds the clientId to the retrieve latest policies by namespace and country public params

func (*RetrieveLatestPoliciesByNamespaceAndCountryPublicParams) SetContext added in v0.84.0

SetContext adds the context to the retrieve latest policies by namespace and country public params

func (*RetrieveLatestPoliciesByNamespaceAndCountryPublicParams) SetCountryCode added in v0.84.0

func (o *RetrieveLatestPoliciesByNamespaceAndCountryPublicParams) SetCountryCode(countryCode string)

SetCountryCode adds the countryCode to the retrieve latest policies by namespace and country public params

func (*RetrieveLatestPoliciesByNamespaceAndCountryPublicParams) SetFlightId added in v0.84.0

SetFlightId adds the flightId as the header value for this specific endpoint

func (*RetrieveLatestPoliciesByNamespaceAndCountryPublicParams) SetHTTPClient added in v0.84.0

SetHTTPClient adds the HTTPClient to the retrieve latest policies by namespace and country public params

func (*RetrieveLatestPoliciesByNamespaceAndCountryPublicParams) SetHTTPClientTransport added in v0.84.0

func (o *RetrieveLatestPoliciesByNamespaceAndCountryPublicParams) SetHTTPClientTransport(roundTripper http.RoundTripper)

SetHTTPClient adds the HTTPClient Transport to the retrieve latest policies by namespace and country public params

func (*RetrieveLatestPoliciesByNamespaceAndCountryPublicParams) SetNamespace added in v0.84.0

SetNamespace adds the namespace to the retrieve latest policies by namespace and country public params

func (*RetrieveLatestPoliciesByNamespaceAndCountryPublicParams) SetTimeout added in v0.84.0

SetTimeout adds the timeout to the retrieve latest policies by namespace and country public params

func (*RetrieveLatestPoliciesByNamespaceAndCountryPublicParams) WithClientID added in v0.84.0

WithClientID adds the clientID to the retrieve latest policies by namespace and country public params

func (*RetrieveLatestPoliciesByNamespaceAndCountryPublicParams) WithContext added in v0.84.0

WithContext adds the context to the retrieve latest policies by namespace and country public params

func (*RetrieveLatestPoliciesByNamespaceAndCountryPublicParams) WithCountryCode added in v0.84.0

WithCountryCode adds the countryCode to the retrieve latest policies by namespace and country public params

func (*RetrieveLatestPoliciesByNamespaceAndCountryPublicParams) WithHTTPClient added in v0.84.0

WithHTTPClient adds the HTTPClient to the retrieve latest policies by namespace and country public params

func (*RetrieveLatestPoliciesByNamespaceAndCountryPublicParams) WithNamespace added in v0.84.0

WithNamespace adds the namespace to the retrieve latest policies by namespace and country public params

func (*RetrieveLatestPoliciesByNamespaceAndCountryPublicParams) WithTimeout added in v0.84.0

WithTimeout adds the timeout to the retrieve latest policies by namespace and country public params

func (*RetrieveLatestPoliciesByNamespaceAndCountryPublicParams) WriteToRequest added in v0.84.0

WriteToRequest writes these params to a swagger request

type RetrieveLatestPoliciesByNamespaceAndCountryPublicReader added in v0.84.0

type RetrieveLatestPoliciesByNamespaceAndCountryPublicReader struct {
	// contains filtered or unexported fields
}

RetrieveLatestPoliciesByNamespaceAndCountryPublicReader is a Reader for the RetrieveLatestPoliciesByNamespaceAndCountryPublic structure.

func (*RetrieveLatestPoliciesByNamespaceAndCountryPublicReader) ReadResponse added in v0.84.0

func (o *RetrieveLatestPoliciesByNamespaceAndCountryPublicReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

Jump to