policy_versions

package
v0.87.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 13, 2026 License: MIT Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client for policy versions API

func (*Client) OldCreatePolicyVersion deprecated added in v0.84.0

Deprecated: 2022-08-10 - Use OldCreatePolicyVersionShort instead.

OldCreatePolicyVersion create a version from country-specific policy Create a version of a particular country-specific policy.

func (*Client) OldCreatePolicyVersionShort added in v0.84.0

func (a *Client) OldCreatePolicyVersionShort(params *OldCreatePolicyVersionParams, authInfo runtime.ClientAuthInfoWriter) (*OldCreatePolicyVersionCreated, error)

OldCreatePolicyVersionShort create a version from country-specific policy Create a version of a particular country-specific policy.

func (*Client) OldPublishPolicyVersion deprecated added in v0.84.0

Deprecated: 2022-08-10 - Use OldPublishPolicyVersionShort instead.

OldPublishPolicyVersion manually publish a version from country-specific policy Manually publish a version of a particular country-specific policy.

func (*Client) OldPublishPolicyVersionShort added in v0.84.0

func (a *Client) OldPublishPolicyVersionShort(params *OldPublishPolicyVersionParams, authInfo runtime.ClientAuthInfoWriter) (*OldPublishPolicyVersionOK, error)

OldPublishPolicyVersionShort manually publish a version from country-specific policy Manually publish a version of a particular country-specific policy.

func (*Client) OldRetrieveSinglePolicyVersion deprecated added in v0.84.0

Deprecated: 2022-08-10 - Use OldRetrieveSinglePolicyVersionShort instead.

OldRetrieveSinglePolicyVersion retrieve a version from country-specific policy Retrieve a version of a particular country specific policy. If version is not provided, the Legal Service will assume caller requesting all versions from country-specific policy.

func (*Client) OldRetrieveSinglePolicyVersionShort added in v0.84.0

func (a *Client) OldRetrieveSinglePolicyVersionShort(params *OldRetrieveSinglePolicyVersionParams, authInfo runtime.ClientAuthInfoWriter) (*OldRetrieveSinglePolicyVersionOK, error)

OldRetrieveSinglePolicyVersionShort retrieve a version from country-specific policy Retrieve a version of a particular country specific policy. If version is not provided, the Legal Service will assume caller requesting all versions from country-specific policy.

func (*Client) OldUpdatePolicyVersion deprecated added in v0.84.0

Deprecated: 2022-08-10 - Use OldUpdatePolicyVersionShort instead.

OldUpdatePolicyVersion update a version of policy Update a particular policy version.

func (*Client) OldUpdatePolicyVersionShort added in v0.84.0

func (a *Client) OldUpdatePolicyVersionShort(params *OldUpdatePolicyVersionParams, authInfo runtime.ClientAuthInfoWriter) (*OldUpdatePolicyVersionOK, error)

OldUpdatePolicyVersionShort update a version of policy Update a particular policy version.

func (*Client) SetTransport

func (a *Client) SetTransport(transport runtime.ClientTransport)

SetTransport changes the transport on the client

type ClientService

ClientService is the interface for Client methods

func New

func New(transport runtime.ClientTransport, formats strfmt.Registry) ClientService

New creates a new policy versions API client.

type OldCreatePolicyVersionBadRequest added in v0.84.0

type OldCreatePolicyVersionBadRequest struct {
	Payload *legalclientmodels.ErrorEntity
}

OldCreatePolicyVersionBadRequest handles this case with default header values.

<table><tr><td>NumericErrorCode</td><td>ErrorCode</td></tr><tr><td>40033</td><td>errors.net.accelbyte.platform.legal.invalid_policy</td></tr></table>

func NewOldCreatePolicyVersionBadRequest added in v0.84.0

func NewOldCreatePolicyVersionBadRequest() *OldCreatePolicyVersionBadRequest

NewOldCreatePolicyVersionBadRequest creates a OldCreatePolicyVersionBadRequest with default headers values

func (*OldCreatePolicyVersionBadRequest) Error added in v0.84.0

func (*OldCreatePolicyVersionBadRequest) GetPayload added in v0.84.0

func (*OldCreatePolicyVersionBadRequest) ToJSONString added in v0.84.0

func (o *OldCreatePolicyVersionBadRequest) ToJSONString() string

type OldCreatePolicyVersionCreated added in v0.84.0

type OldCreatePolicyVersionCreated struct {
	Payload *legalclientmodels.CreatePolicyVersionResponse
}

OldCreatePolicyVersionCreated handles this case with default header values.

successful operation

func NewOldCreatePolicyVersionCreated added in v0.84.0

func NewOldCreatePolicyVersionCreated() *OldCreatePolicyVersionCreated

NewOldCreatePolicyVersionCreated creates a OldCreatePolicyVersionCreated with default headers values

func (*OldCreatePolicyVersionCreated) Error added in v0.84.0

func (*OldCreatePolicyVersionCreated) GetPayload added in v0.84.0

func (*OldCreatePolicyVersionCreated) ToJSONString added in v0.84.0

func (o *OldCreatePolicyVersionCreated) ToJSONString() string

type OldCreatePolicyVersionParams added in v0.84.0

type OldCreatePolicyVersionParams struct {

	/*RetryPolicy*/
	RetryPolicy *utils.Retry
	/*Body*/
	Body *legalclientmodels.CreatePolicyVersionRequest
	/*PolicyID
	  Policy Id

	*/
	PolicyID string

	AuthInfoWriter runtime.ClientAuthInfoWriter
	Context        context.Context
	HTTPClient     *http.Client

	// XFlightId is an optional parameter from this SDK
	XFlightId *string
	// contains filtered or unexported fields
}

OldCreatePolicyVersionParams contains all the parameters to send to the API endpoint for the old create policy version operation typically these are written to a http.Request

func NewOldCreatePolicyVersionParams added in v0.84.0

func NewOldCreatePolicyVersionParams() *OldCreatePolicyVersionParams

NewOldCreatePolicyVersionParams creates a new OldCreatePolicyVersionParams object with the default values initialized.

func NewOldCreatePolicyVersionParamsWithContext added in v0.84.0

func NewOldCreatePolicyVersionParamsWithContext(ctx context.Context) *OldCreatePolicyVersionParams

NewOldCreatePolicyVersionParamsWithContext creates a new OldCreatePolicyVersionParams object with the default values initialized, and the ability to set a context for a request

func NewOldCreatePolicyVersionParamsWithHTTPClient added in v0.84.0

func NewOldCreatePolicyVersionParamsWithHTTPClient(client *http.Client) *OldCreatePolicyVersionParams

NewOldCreatePolicyVersionParamsWithHTTPClient creates a new OldCreatePolicyVersionParams object with the default values initialized, and the ability to set a custom HTTPClient for a request

func NewOldCreatePolicyVersionParamsWithTimeout added in v0.84.0

func NewOldCreatePolicyVersionParamsWithTimeout(timeout time.Duration) *OldCreatePolicyVersionParams

NewOldCreatePolicyVersionParamsWithTimeout creates a new OldCreatePolicyVersionParams object with the default values initialized, and the ability to set a timeout on a request

func (*OldCreatePolicyVersionParams) SetAuthInfoWriter added in v0.84.0

func (o *OldCreatePolicyVersionParams) SetAuthInfoWriter(authInfoWriter runtime.ClientAuthInfoWriter)

SetAuthInfoWriter adds the authInfoWriter to the old create policy version params

func (*OldCreatePolicyVersionParams) SetBody added in v0.84.0

SetBody adds the body to the old create policy version params

func (*OldCreatePolicyVersionParams) SetContext added in v0.84.0

func (o *OldCreatePolicyVersionParams) SetContext(ctx context.Context)

SetContext adds the context to the old create policy version params

func (*OldCreatePolicyVersionParams) SetFlightId added in v0.84.0

func (o *OldCreatePolicyVersionParams) SetFlightId(flightId string)

SetFlightId adds the flightId as the header value for this specific endpoint

func (*OldCreatePolicyVersionParams) SetHTTPClient added in v0.84.0

func (o *OldCreatePolicyVersionParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the old create policy version params

func (*OldCreatePolicyVersionParams) SetHTTPClientTransport added in v0.84.0

func (o *OldCreatePolicyVersionParams) SetHTTPClientTransport(roundTripper http.RoundTripper)

SetHTTPClient adds the HTTPClient Transport to the old create policy version params

func (*OldCreatePolicyVersionParams) SetPolicyID added in v0.84.0

func (o *OldCreatePolicyVersionParams) SetPolicyID(policyID string)

SetPolicyID adds the policyId to the old create policy version params

func (*OldCreatePolicyVersionParams) SetTimeout added in v0.84.0

func (o *OldCreatePolicyVersionParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the old create policy version params

func (*OldCreatePolicyVersionParams) WithBody added in v0.84.0

WithBody adds the body to the old create policy version params

func (*OldCreatePolicyVersionParams) WithContext added in v0.84.0

WithContext adds the context to the old create policy version params

func (*OldCreatePolicyVersionParams) WithHTTPClient added in v0.84.0

WithHTTPClient adds the HTTPClient to the old create policy version params

func (*OldCreatePolicyVersionParams) WithPolicyID added in v0.84.0

WithPolicyID adds the policyID to the old create policy version params

func (*OldCreatePolicyVersionParams) WithTimeout added in v0.84.0

WithTimeout adds the timeout to the old create policy version params

func (*OldCreatePolicyVersionParams) WriteToRequest added in v0.84.0

WriteToRequest writes these params to a swagger request

type OldCreatePolicyVersionReader added in v0.84.0

type OldCreatePolicyVersionReader struct {
	// contains filtered or unexported fields
}

OldCreatePolicyVersionReader is a Reader for the OldCreatePolicyVersion structure.

func (*OldCreatePolicyVersionReader) ReadResponse added in v0.84.0

func (o *OldCreatePolicyVersionReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type OldPublishPolicyVersionBadRequest added in v0.84.0

type OldPublishPolicyVersionBadRequest struct {
	Payload *legalclientmodels.ErrorEntity
}

OldPublishPolicyVersionBadRequest handles this case with default header values.

<table><tr><td>NumericErrorCode</td><td>ErrorCode</td></tr><tr><td>40035</td><td>errors.net.accelbyte.platform.legal.invalid_policy_version</td></tr><tr><td>40046</td><td>errors.net.accelbyte.platform.legal.default_selection_not_provided</td></tr><tr><td>40030</td><td>errors.net.accelbyte.platform.legal.localized_policy_version_not_provided</td></tr></table>

func NewOldPublishPolicyVersionBadRequest added in v0.84.0

func NewOldPublishPolicyVersionBadRequest() *OldPublishPolicyVersionBadRequest

NewOldPublishPolicyVersionBadRequest creates a OldPublishPolicyVersionBadRequest with default headers values

func (*OldPublishPolicyVersionBadRequest) Error added in v0.84.0

func (*OldPublishPolicyVersionBadRequest) GetPayload added in v0.84.0

func (*OldPublishPolicyVersionBadRequest) ToJSONString added in v0.84.0

func (o *OldPublishPolicyVersionBadRequest) ToJSONString() string

type OldPublishPolicyVersionConflict added in v0.84.0

type OldPublishPolicyVersionConflict struct {
	Payload *legalclientmodels.ErrorEntity
}

OldPublishPolicyVersionConflict handles this case with default header values.

<table><tr><td>NumericErrorCode</td><td>ErrorCode</td></tr><tr><td>40039</td><td>errors.net.accelbyte.platform.legal.localized_policy_version_already_latest</td></tr><tr><td>40043</td><td>errors.net.accelbyte.platform.legal.localized_policy_version_already_publish</td></tr></table>

func NewOldPublishPolicyVersionConflict added in v0.84.0

func NewOldPublishPolicyVersionConflict() *OldPublishPolicyVersionConflict

NewOldPublishPolicyVersionConflict creates a OldPublishPolicyVersionConflict with default headers values

func (*OldPublishPolicyVersionConflict) Error added in v0.84.0

func (*OldPublishPolicyVersionConflict) GetPayload added in v0.84.0

func (*OldPublishPolicyVersionConflict) ToJSONString added in v0.84.0

func (o *OldPublishPolicyVersionConflict) ToJSONString() string

type OldPublishPolicyVersionOK added in v0.84.0

type OldPublishPolicyVersionOK struct {
}

OldPublishPolicyVersionOK handles this case with default header values.

operation successful

func NewOldPublishPolicyVersionOK added in v0.84.0

func NewOldPublishPolicyVersionOK() *OldPublishPolicyVersionOK

NewOldPublishPolicyVersionOK creates a OldPublishPolicyVersionOK with default headers values

func (*OldPublishPolicyVersionOK) Error added in v0.84.0

func (o *OldPublishPolicyVersionOK) Error() string

type OldPublishPolicyVersionParams added in v0.84.0

type OldPublishPolicyVersionParams struct {

	/*RetryPolicy*/
	RetryPolicy *utils.Retry
	/*PolicyVersionID
	  Policy Version Id

	*/
	PolicyVersionID string
	/*ShouldNotify
	  Should Notify

	*/
	ShouldNotify *bool

	AuthInfoWriter runtime.ClientAuthInfoWriter
	Context        context.Context
	HTTPClient     *http.Client

	// XFlightId is an optional parameter from this SDK
	XFlightId *string
	// contains filtered or unexported fields
}

OldPublishPolicyVersionParams contains all the parameters to send to the API endpoint for the old publish policy version operation typically these are written to a http.Request

func NewOldPublishPolicyVersionParams added in v0.84.0

func NewOldPublishPolicyVersionParams() *OldPublishPolicyVersionParams

NewOldPublishPolicyVersionParams creates a new OldPublishPolicyVersionParams object with the default values initialized.

func NewOldPublishPolicyVersionParamsWithContext added in v0.84.0

func NewOldPublishPolicyVersionParamsWithContext(ctx context.Context) *OldPublishPolicyVersionParams

NewOldPublishPolicyVersionParamsWithContext creates a new OldPublishPolicyVersionParams object with the default values initialized, and the ability to set a context for a request

func NewOldPublishPolicyVersionParamsWithHTTPClient added in v0.84.0

func NewOldPublishPolicyVersionParamsWithHTTPClient(client *http.Client) *OldPublishPolicyVersionParams

NewOldPublishPolicyVersionParamsWithHTTPClient creates a new OldPublishPolicyVersionParams object with the default values initialized, and the ability to set a custom HTTPClient for a request

func NewOldPublishPolicyVersionParamsWithTimeout added in v0.84.0

func NewOldPublishPolicyVersionParamsWithTimeout(timeout time.Duration) *OldPublishPolicyVersionParams

NewOldPublishPolicyVersionParamsWithTimeout creates a new OldPublishPolicyVersionParams object with the default values initialized, and the ability to set a timeout on a request

func (*OldPublishPolicyVersionParams) SetAuthInfoWriter added in v0.84.0

func (o *OldPublishPolicyVersionParams) SetAuthInfoWriter(authInfoWriter runtime.ClientAuthInfoWriter)

SetAuthInfoWriter adds the authInfoWriter to the old publish policy version params

func (*OldPublishPolicyVersionParams) SetContext added in v0.84.0

func (o *OldPublishPolicyVersionParams) SetContext(ctx context.Context)

SetContext adds the context to the old publish policy version params

func (*OldPublishPolicyVersionParams) SetFlightId added in v0.84.0

func (o *OldPublishPolicyVersionParams) SetFlightId(flightId string)

SetFlightId adds the flightId as the header value for this specific endpoint

func (*OldPublishPolicyVersionParams) SetHTTPClient added in v0.84.0

func (o *OldPublishPolicyVersionParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the old publish policy version params

func (*OldPublishPolicyVersionParams) SetHTTPClientTransport added in v0.84.0

func (o *OldPublishPolicyVersionParams) SetHTTPClientTransport(roundTripper http.RoundTripper)

SetHTTPClient adds the HTTPClient Transport to the old publish policy version params

func (*OldPublishPolicyVersionParams) SetPolicyVersionID added in v0.84.0

func (o *OldPublishPolicyVersionParams) SetPolicyVersionID(policyVersionID string)

SetPolicyVersionID adds the policyVersionId to the old publish policy version params

func (*OldPublishPolicyVersionParams) SetShouldNotify added in v0.84.0

func (o *OldPublishPolicyVersionParams) SetShouldNotify(shouldNotify *bool)

SetShouldNotify adds the shouldNotify to the old publish policy version params

func (*OldPublishPolicyVersionParams) SetTimeout added in v0.84.0

func (o *OldPublishPolicyVersionParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the old publish policy version params

func (*OldPublishPolicyVersionParams) WithContext added in v0.84.0

WithContext adds the context to the old publish policy version params

func (*OldPublishPolicyVersionParams) WithHTTPClient added in v0.84.0

WithHTTPClient adds the HTTPClient to the old publish policy version params

func (*OldPublishPolicyVersionParams) WithPolicyVersionID added in v0.84.0

func (o *OldPublishPolicyVersionParams) WithPolicyVersionID(policyVersionID string) *OldPublishPolicyVersionParams

WithPolicyVersionID adds the policyVersionID to the old publish policy version params

func (*OldPublishPolicyVersionParams) WithShouldNotify added in v0.84.0

func (o *OldPublishPolicyVersionParams) WithShouldNotify(shouldNotify *bool) *OldPublishPolicyVersionParams

WithShouldNotify adds the shouldNotify to the old publish policy version params

func (*OldPublishPolicyVersionParams) WithTimeout added in v0.84.0

WithTimeout adds the timeout to the old publish policy version params

func (*OldPublishPolicyVersionParams) WriteToRequest added in v0.84.0

WriteToRequest writes these params to a swagger request

type OldPublishPolicyVersionReader added in v0.84.0

type OldPublishPolicyVersionReader struct {
	// contains filtered or unexported fields
}

OldPublishPolicyVersionReader is a Reader for the OldPublishPolicyVersion structure.

func (*OldPublishPolicyVersionReader) ReadResponse added in v0.84.0

func (o *OldPublishPolicyVersionReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type OldRetrieveSinglePolicyVersionNotFound added in v0.84.0

type OldRetrieveSinglePolicyVersionNotFound struct {
	Payload *legalclientmodels.ErrorEntity
}

OldRetrieveSinglePolicyVersionNotFound handles this case with default header values.

<table><tr><td>NumericErrorCode</td><td>ErrorCode</td></tr><tr><td>40036</td><td>errors.net.accelbyte.platform.legal.policy_version_id_not_found</td></tr></table>

func NewOldRetrieveSinglePolicyVersionNotFound added in v0.84.0

func NewOldRetrieveSinglePolicyVersionNotFound() *OldRetrieveSinglePolicyVersionNotFound

NewOldRetrieveSinglePolicyVersionNotFound creates a OldRetrieveSinglePolicyVersionNotFound with default headers values

func (*OldRetrieveSinglePolicyVersionNotFound) Error added in v0.84.0

func (*OldRetrieveSinglePolicyVersionNotFound) GetPayload added in v0.84.0

func (*OldRetrieveSinglePolicyVersionNotFound) ToJSONString added in v0.84.0

type OldRetrieveSinglePolicyVersionOK added in v0.84.0

type OldRetrieveSinglePolicyVersionOK struct {
	Payload []*legalclientmodels.RetrievePolicyVersionResponse
}

OldRetrieveSinglePolicyVersionOK handles this case with default header values.

successful operation

func NewOldRetrieveSinglePolicyVersionOK added in v0.84.0

func NewOldRetrieveSinglePolicyVersionOK() *OldRetrieveSinglePolicyVersionOK

NewOldRetrieveSinglePolicyVersionOK creates a OldRetrieveSinglePolicyVersionOK with default headers values

func (*OldRetrieveSinglePolicyVersionOK) Error added in v0.84.0

func (*OldRetrieveSinglePolicyVersionOK) GetPayload added in v0.84.0

func (*OldRetrieveSinglePolicyVersionOK) ToJSONString added in v0.84.0

func (o *OldRetrieveSinglePolicyVersionOK) ToJSONString() string

type OldRetrieveSinglePolicyVersionParams added in v0.84.0

type OldRetrieveSinglePolicyVersionParams struct {

	/*RetryPolicy*/
	RetryPolicy *utils.Retry
	/*PolicyID
	  Policy Id

	*/
	PolicyID string
	/*VersionID
	  Version Id

	*/
	VersionID *string

	AuthInfoWriter runtime.ClientAuthInfoWriter
	Context        context.Context
	HTTPClient     *http.Client

	// XFlightId is an optional parameter from this SDK
	XFlightId *string
	// contains filtered or unexported fields
}

OldRetrieveSinglePolicyVersionParams contains all the parameters to send to the API endpoint for the old retrieve single policy version operation typically these are written to a http.Request

func NewOldRetrieveSinglePolicyVersionParams added in v0.84.0

func NewOldRetrieveSinglePolicyVersionParams() *OldRetrieveSinglePolicyVersionParams

NewOldRetrieveSinglePolicyVersionParams creates a new OldRetrieveSinglePolicyVersionParams object with the default values initialized.

func NewOldRetrieveSinglePolicyVersionParamsWithContext added in v0.84.0

func NewOldRetrieveSinglePolicyVersionParamsWithContext(ctx context.Context) *OldRetrieveSinglePolicyVersionParams

NewOldRetrieveSinglePolicyVersionParamsWithContext creates a new OldRetrieveSinglePolicyVersionParams object with the default values initialized, and the ability to set a context for a request

func NewOldRetrieveSinglePolicyVersionParamsWithHTTPClient added in v0.84.0

func NewOldRetrieveSinglePolicyVersionParamsWithHTTPClient(client *http.Client) *OldRetrieveSinglePolicyVersionParams

NewOldRetrieveSinglePolicyVersionParamsWithHTTPClient creates a new OldRetrieveSinglePolicyVersionParams object with the default values initialized, and the ability to set a custom HTTPClient for a request

func NewOldRetrieveSinglePolicyVersionParamsWithTimeout added in v0.84.0

func NewOldRetrieveSinglePolicyVersionParamsWithTimeout(timeout time.Duration) *OldRetrieveSinglePolicyVersionParams

NewOldRetrieveSinglePolicyVersionParamsWithTimeout creates a new OldRetrieveSinglePolicyVersionParams object with the default values initialized, and the ability to set a timeout on a request

func (*OldRetrieveSinglePolicyVersionParams) SetAuthInfoWriter added in v0.84.0

func (o *OldRetrieveSinglePolicyVersionParams) SetAuthInfoWriter(authInfoWriter runtime.ClientAuthInfoWriter)

SetAuthInfoWriter adds the authInfoWriter to the old retrieve single policy version params

func (*OldRetrieveSinglePolicyVersionParams) SetContext added in v0.84.0

SetContext adds the context to the old retrieve single policy version params

func (*OldRetrieveSinglePolicyVersionParams) SetFlightId added in v0.84.0

func (o *OldRetrieveSinglePolicyVersionParams) SetFlightId(flightId string)

SetFlightId adds the flightId as the header value for this specific endpoint

func (*OldRetrieveSinglePolicyVersionParams) SetHTTPClient added in v0.84.0

func (o *OldRetrieveSinglePolicyVersionParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the old retrieve single policy version params

func (*OldRetrieveSinglePolicyVersionParams) SetHTTPClientTransport added in v0.84.0

func (o *OldRetrieveSinglePolicyVersionParams) SetHTTPClientTransport(roundTripper http.RoundTripper)

SetHTTPClient adds the HTTPClient Transport to the old retrieve single policy version params

func (*OldRetrieveSinglePolicyVersionParams) SetPolicyID added in v0.84.0

func (o *OldRetrieveSinglePolicyVersionParams) SetPolicyID(policyID string)

SetPolicyID adds the policyId to the old retrieve single policy version params

func (*OldRetrieveSinglePolicyVersionParams) SetTimeout added in v0.84.0

func (o *OldRetrieveSinglePolicyVersionParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the old retrieve single policy version params

func (*OldRetrieveSinglePolicyVersionParams) SetVersionID added in v0.84.0

func (o *OldRetrieveSinglePolicyVersionParams) SetVersionID(versionID *string)

SetVersionID adds the versionId to the old retrieve single policy version params

func (*OldRetrieveSinglePolicyVersionParams) WithContext added in v0.84.0

WithContext adds the context to the old retrieve single policy version params

func (*OldRetrieveSinglePolicyVersionParams) WithHTTPClient added in v0.84.0

WithHTTPClient adds the HTTPClient to the old retrieve single policy version params

func (*OldRetrieveSinglePolicyVersionParams) WithPolicyID added in v0.84.0

WithPolicyID adds the policyID to the old retrieve single policy version params

func (*OldRetrieveSinglePolicyVersionParams) WithTimeout added in v0.84.0

WithTimeout adds the timeout to the old retrieve single policy version params

func (*OldRetrieveSinglePolicyVersionParams) WithVersionID added in v0.84.0

WithVersionID adds the versionID to the old retrieve single policy version params

func (*OldRetrieveSinglePolicyVersionParams) WriteToRequest added in v0.84.0

WriteToRequest writes these params to a swagger request

type OldRetrieveSinglePolicyVersionReader added in v0.84.0

type OldRetrieveSinglePolicyVersionReader struct {
	// contains filtered or unexported fields
}

OldRetrieveSinglePolicyVersionReader is a Reader for the OldRetrieveSinglePolicyVersion structure.

func (*OldRetrieveSinglePolicyVersionReader) ReadResponse added in v0.84.0

func (o *OldRetrieveSinglePolicyVersionReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type OldUpdatePolicyVersionBadRequest added in v0.84.0

type OldUpdatePolicyVersionBadRequest struct {
	Payload *legalclientmodels.ErrorEntity
}

OldUpdatePolicyVersionBadRequest handles this case with default header values.

<table><tr><td>NumericErrorCode</td><td>ErrorCode</td></tr><tr><td>40035</td><td>errors.net.accelbyte.platform.legal.invalid_policy_version</td></tr><tr><td>40042</td><td>errors.net.accelbyte.platform.legal.policy_version_freezed</td></tr></table>

func NewOldUpdatePolicyVersionBadRequest added in v0.84.0

func NewOldUpdatePolicyVersionBadRequest() *OldUpdatePolicyVersionBadRequest

NewOldUpdatePolicyVersionBadRequest creates a OldUpdatePolicyVersionBadRequest with default headers values

func (*OldUpdatePolicyVersionBadRequest) Error added in v0.84.0

func (*OldUpdatePolicyVersionBadRequest) GetPayload added in v0.84.0

func (*OldUpdatePolicyVersionBadRequest) ToJSONString added in v0.84.0

func (o *OldUpdatePolicyVersionBadRequest) ToJSONString() string

type OldUpdatePolicyVersionConflict added in v0.84.0

type OldUpdatePolicyVersionConflict struct {
	Payload *legalclientmodels.ErrorEntity
}

OldUpdatePolicyVersionConflict handles this case with default header values.

<table><tr><td>NumericErrorCode</td><td>ErrorCode</td></tr><tr><td>40043</td><td>errors.net.accelbyte.platform.legal.localized_policy_version_already_exist</td></tr></table>

func NewOldUpdatePolicyVersionConflict added in v0.84.0

func NewOldUpdatePolicyVersionConflict() *OldUpdatePolicyVersionConflict

NewOldUpdatePolicyVersionConflict creates a OldUpdatePolicyVersionConflict with default headers values

func (*OldUpdatePolicyVersionConflict) Error added in v0.84.0

func (*OldUpdatePolicyVersionConflict) GetPayload added in v0.84.0

func (*OldUpdatePolicyVersionConflict) ToJSONString added in v0.84.0

func (o *OldUpdatePolicyVersionConflict) ToJSONString() string

type OldUpdatePolicyVersionOK added in v0.84.0

type OldUpdatePolicyVersionOK struct {
	Payload *legalclientmodels.UpdatePolicyVersionResponse
}

OldUpdatePolicyVersionOK handles this case with default header values.

successful operation

func NewOldUpdatePolicyVersionOK added in v0.84.0

func NewOldUpdatePolicyVersionOK() *OldUpdatePolicyVersionOK

NewOldUpdatePolicyVersionOK creates a OldUpdatePolicyVersionOK with default headers values

func (*OldUpdatePolicyVersionOK) Error added in v0.84.0

func (o *OldUpdatePolicyVersionOK) Error() string

func (*OldUpdatePolicyVersionOK) GetPayload added in v0.84.0

func (*OldUpdatePolicyVersionOK) ToJSONString added in v0.84.0

func (o *OldUpdatePolicyVersionOK) ToJSONString() string

type OldUpdatePolicyVersionParams added in v0.84.0

type OldUpdatePolicyVersionParams struct {

	/*RetryPolicy*/
	RetryPolicy *utils.Retry
	/*Body*/
	Body *legalclientmodels.UpdatePolicyVersionRequest
	/*PolicyVersionID
	  Policy Version Id

	*/
	PolicyVersionID string

	AuthInfoWriter runtime.ClientAuthInfoWriter
	Context        context.Context
	HTTPClient     *http.Client

	// XFlightId is an optional parameter from this SDK
	XFlightId *string
	// contains filtered or unexported fields
}

OldUpdatePolicyVersionParams contains all the parameters to send to the API endpoint for the old update policy version operation typically these are written to a http.Request

func NewOldUpdatePolicyVersionParams added in v0.84.0

func NewOldUpdatePolicyVersionParams() *OldUpdatePolicyVersionParams

NewOldUpdatePolicyVersionParams creates a new OldUpdatePolicyVersionParams object with the default values initialized.

func NewOldUpdatePolicyVersionParamsWithContext added in v0.84.0

func NewOldUpdatePolicyVersionParamsWithContext(ctx context.Context) *OldUpdatePolicyVersionParams

NewOldUpdatePolicyVersionParamsWithContext creates a new OldUpdatePolicyVersionParams object with the default values initialized, and the ability to set a context for a request

func NewOldUpdatePolicyVersionParamsWithHTTPClient added in v0.84.0

func NewOldUpdatePolicyVersionParamsWithHTTPClient(client *http.Client) *OldUpdatePolicyVersionParams

NewOldUpdatePolicyVersionParamsWithHTTPClient creates a new OldUpdatePolicyVersionParams object with the default values initialized, and the ability to set a custom HTTPClient for a request

func NewOldUpdatePolicyVersionParamsWithTimeout added in v0.84.0

func NewOldUpdatePolicyVersionParamsWithTimeout(timeout time.Duration) *OldUpdatePolicyVersionParams

NewOldUpdatePolicyVersionParamsWithTimeout creates a new OldUpdatePolicyVersionParams object with the default values initialized, and the ability to set a timeout on a request

func (*OldUpdatePolicyVersionParams) SetAuthInfoWriter added in v0.84.0

func (o *OldUpdatePolicyVersionParams) SetAuthInfoWriter(authInfoWriter runtime.ClientAuthInfoWriter)

SetAuthInfoWriter adds the authInfoWriter to the old update policy version params

func (*OldUpdatePolicyVersionParams) SetBody added in v0.84.0

SetBody adds the body to the old update policy version params

func (*OldUpdatePolicyVersionParams) SetContext added in v0.84.0

func (o *OldUpdatePolicyVersionParams) SetContext(ctx context.Context)

SetContext adds the context to the old update policy version params

func (*OldUpdatePolicyVersionParams) SetFlightId added in v0.84.0

func (o *OldUpdatePolicyVersionParams) SetFlightId(flightId string)

SetFlightId adds the flightId as the header value for this specific endpoint

func (*OldUpdatePolicyVersionParams) SetHTTPClient added in v0.84.0

func (o *OldUpdatePolicyVersionParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the old update policy version params

func (*OldUpdatePolicyVersionParams) SetHTTPClientTransport added in v0.84.0

func (o *OldUpdatePolicyVersionParams) SetHTTPClientTransport(roundTripper http.RoundTripper)

SetHTTPClient adds the HTTPClient Transport to the old update policy version params

func (*OldUpdatePolicyVersionParams) SetPolicyVersionID added in v0.84.0

func (o *OldUpdatePolicyVersionParams) SetPolicyVersionID(policyVersionID string)

SetPolicyVersionID adds the policyVersionId to the old update policy version params

func (*OldUpdatePolicyVersionParams) SetTimeout added in v0.84.0

func (o *OldUpdatePolicyVersionParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the old update policy version params

func (*OldUpdatePolicyVersionParams) WithBody added in v0.84.0

WithBody adds the body to the old update policy version params

func (*OldUpdatePolicyVersionParams) WithContext added in v0.84.0

WithContext adds the context to the old update policy version params

func (*OldUpdatePolicyVersionParams) WithHTTPClient added in v0.84.0

WithHTTPClient adds the HTTPClient to the old update policy version params

func (*OldUpdatePolicyVersionParams) WithPolicyVersionID added in v0.84.0

func (o *OldUpdatePolicyVersionParams) WithPolicyVersionID(policyVersionID string) *OldUpdatePolicyVersionParams

WithPolicyVersionID adds the policyVersionID to the old update policy version params

func (*OldUpdatePolicyVersionParams) WithTimeout added in v0.84.0

WithTimeout adds the timeout to the old update policy version params

func (*OldUpdatePolicyVersionParams) WriteToRequest added in v0.84.0

WriteToRequest writes these params to a swagger request

type OldUpdatePolicyVersionReader added in v0.84.0

type OldUpdatePolicyVersionReader struct {
	// contains filtered or unexported fields
}

OldUpdatePolicyVersionReader is a Reader for the OldUpdatePolicyVersion structure.

func (*OldUpdatePolicyVersionReader) ReadResponse added in v0.84.0

func (o *OldUpdatePolicyVersionReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

Jump to