Documentation
¶
Index ¶
- Constants
- type BulkUserProgressionRequest
- type ClaimableRewards
- type ClaimableUserSeasonInfo
- type ErrorEntity
- type ExcessStrategy
- type ExpGrantHistoryInfo
- type ExpGrantHistoryPagingSlicedResult
- type FieldValidationError
- type FullSeasonInfo
- type Image
- type ItemReference
- type ItemReferenceInfo
- type ListSeasonInfo
- type ListSeasonInfoPagingSlicedResult
- type ListUserSeasonInfo
- type ListUserSeasonInfoPagingSlicedResult
- type Localization
- type LocalizedPassInfo
- type LocalizedSeasonInfo
- type Ownership
- type Paging
- type PassCreate
- type PassInfo
- type PassUpdate
- type Permission
- type ReasonTagsResult
- type RewardCreate
- type RewardCurrency
- type RewardInfo
- type RewardUpdate
- type SeasonCloneRequest
- type SeasonCreate
- type SeasonInfo
- type SeasonSummary
- type SeasonUpdate
- type Tier
- type TierCreate
- type TierInput
- type TierPagingSlicedResult
- type TierReorder
- type UserExpGrant
- type UserPassGrant
- type UserPurchasable
- type UserRewardClaim
- type UserSeasonSummary
- type UserTierGrant
- type ValidationErrorEntity
Constants ¶
const ( // ExcessStrategyMethodCURRENCY captures enum value "CURRENCY" ExcessStrategyMethodCURRENCY string = "CURRENCY" // ExcessStrategyMethodNONE captures enum value "NONE" ExcessStrategyMethodNONE string = "NONE" )
const ( // ExpGrantHistoryInfoSourcePAIDFOR captures enum value "PAID_FOR" ExpGrantHistoryInfoSourcePAIDFOR string = "PAID_FOR" // ExpGrantHistoryInfoSourceSWEAT captures enum value "SWEAT" ExpGrantHistoryInfoSourceSWEAT string = "SWEAT" )
const ( // ListSeasonInfoStatusDRAFT captures enum value "DRAFT" ListSeasonInfoStatusDRAFT string = "DRAFT" // ListSeasonInfoStatusPUBLISHED captures enum value "PUBLISHED" ListSeasonInfoStatusPUBLISHED string = "PUBLISHED" // ListSeasonInfoStatusRETIRED captures enum value "RETIRED" ListSeasonInfoStatusRETIRED string = "RETIRED" )
const ( // LocalizedSeasonInfoStatusDRAFT captures enum value "DRAFT" LocalizedSeasonInfoStatusDRAFT string = "DRAFT" // LocalizedSeasonInfoStatusPUBLISHED captures enum value "PUBLISHED" LocalizedSeasonInfoStatusPUBLISHED string = "PUBLISHED" // LocalizedSeasonInfoStatusRETIRED captures enum value "RETIRED" LocalizedSeasonInfoStatusRETIRED string = "RETIRED" )
const ( // RewardCreateTypeCURRENCY captures enum value "CURRENCY" RewardCreateTypeCURRENCY string = "CURRENCY" // RewardCreateTypeITEM captures enum value "ITEM" RewardCreateTypeITEM string = "ITEM" )
const ( // RewardInfoItemTypeAPP captures enum value "APP" RewardInfoItemTypeAPP string = "APP" // RewardInfoItemTypeBUNDLE captures enum value "BUNDLE" RewardInfoItemTypeBUNDLE string = "BUNDLE" // RewardInfoItemTypeCODE captures enum value "CODE" RewardInfoItemTypeCODE string = "CODE" // RewardInfoItemTypeCOINS captures enum value "COINS" RewardInfoItemTypeCOINS string = "COINS" // RewardInfoItemTypeEXTENSION captures enum value "EXTENSION" RewardInfoItemTypeEXTENSION string = "EXTENSION" // RewardInfoItemTypeINGAMEITEM captures enum value "INGAMEITEM" RewardInfoItemTypeINGAMEITEM string = "INGAMEITEM" // RewardInfoItemTypeLOOTBOX captures enum value "LOOTBOX" RewardInfoItemTypeLOOTBOX string = "LOOTBOX" // RewardInfoItemTypeMEDIA captures enum value "MEDIA" RewardInfoItemTypeMEDIA string = "MEDIA" // RewardInfoItemTypeOPTIONBOX captures enum value "OPTIONBOX" RewardInfoItemTypeOPTIONBOX string = "OPTIONBOX" // RewardInfoItemTypeSEASON captures enum value "SEASON" RewardInfoItemTypeSEASON string = "SEASON" // RewardInfoItemTypeSUBSCRIPTION captures enum value "SUBSCRIPTION" RewardInfoItemTypeSUBSCRIPTION string = "SUBSCRIPTION" )
const ( // RewardInfoTypeCURRENCY captures enum value "CURRENCY" RewardInfoTypeCURRENCY string = "CURRENCY" // RewardInfoTypeITEM captures enum value "ITEM" RewardInfoTypeITEM string = "ITEM" )
const ( // RewardUpdateTypeCURRENCY captures enum value "CURRENCY" RewardUpdateTypeCURRENCY string = "CURRENCY" // RewardUpdateTypeITEM captures enum value "ITEM" RewardUpdateTypeITEM string = "ITEM" )
const ( // SeasonInfoStatusDRAFT captures enum value "DRAFT" SeasonInfoStatusDRAFT string = "DRAFT" // SeasonInfoStatusPUBLISHED captures enum value "PUBLISHED" SeasonInfoStatusPUBLISHED string = "PUBLISHED" // SeasonInfoStatusRETIRED captures enum value "RETIRED" SeasonInfoStatusRETIRED string = "RETIRED" )
const ( // SeasonSummaryStatusDRAFT captures enum value "DRAFT" SeasonSummaryStatusDRAFT string = "DRAFT" // SeasonSummaryStatusPUBLISHED captures enum value "PUBLISHED" SeasonSummaryStatusPUBLISHED string = "PUBLISHED" // SeasonSummaryStatusRETIRED captures enum value "RETIRED" SeasonSummaryStatusRETIRED string = "RETIRED" )
const ( // UserExpGrantSourcePAIDFOR captures enum value "PAID_FOR" UserExpGrantSourcePAIDFOR string = "PAID_FOR" // UserExpGrantSourceSWEAT captures enum value "SWEAT" UserExpGrantSourceSWEAT string = "SWEAT" )
const ( // UserTierGrantSourcePAIDFOR captures enum value "PAID_FOR" UserTierGrantSourcePAIDFOR string = "PAID_FOR" // UserTierGrantSourceSWEAT captures enum value "SWEAT" UserTierGrantSourceSWEAT string = "SWEAT" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BulkUserProgressionRequest ¶ added in v0.30.0
type BulkUserProgressionRequest struct {
// userids
UserIds []string `json:"userIds,omitempty"`
}
BulkUserProgressionRequest Bulk user progression request
swagger:model Bulk user progression request.
func (*BulkUserProgressionRequest) MarshalBinary ¶ added in v0.30.0
func (m *BulkUserProgressionRequest) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*BulkUserProgressionRequest) UnmarshalBinary ¶ added in v0.30.0
func (m *BulkUserProgressionRequest) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type ClaimableRewards ¶
type ClaimableRewards struct {
// Claiming rewards, zero based tier index as key, rewards per pass as value
// Required: true
ClaimingRewards interface{} `json:"claimingRewards"`
// To claim rewards, zero based tier index as key, rewards per pass as value
// Required: true
ToClaimRewards interface{} `json:"toClaimRewards"`
}
ClaimableRewards Claimable rewards
swagger:model Claimable rewards.
func (*ClaimableRewards) MarshalBinary ¶
func (m *ClaimableRewards) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*ClaimableRewards) UnmarshalBinary ¶
func (m *ClaimableRewards) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type ClaimableUserSeasonInfo ¶
type ClaimableUserSeasonInfo struct {
// Claiming rewards, zero based tier index as key, rewards per pass as value
// Required: true
ClaimingRewards interface{} `json:"claimingRewards"`
// whether cleared all tiers
// Required: true
Cleared *bool `json:"cleared"`
// created at
// Required: true
// Format: date-time
CreatedAt strfmt.DateTime `json:"createdAt"`
// gained exp for current tier
// Required: true
// Format: int32
CurrentExp *int32 `json:"currentExp"`
// current tier index, zero based
// Required: true
// Format: int32
CurrentTierIndex *int32 `json:"currentTierIndex"`
// enroll date time
// Required: true
// Format: date-time
EnrolledAt strfmt.DateTime `json:"enrolledAt"`
// enrolled passes
// Unique: true
// Required: true
EnrolledPasses []string `json:"enrolledPasses"`
// id
// Required: true
ID *string `json:"id"`
// last tier index, zero based
// Required: true
// Format: int32
LastTierIndex *int32 `json:"lastTierIndex"`
// namespace
// Required: true
Namespace *string `json:"namespace"`
// required exp for current tier
// Required: true
// Format: int32
RequiredExp *int32 `json:"requiredExp"`
// season summary
Season *SeasonSummary `json:"season,omitempty"`
// season id
// Required: true
SeasonID *string `json:"seasonId"`
// To claim rewards, zero based tier index as key, rewards per pass as value
// Required: true
ToClaimRewards interface{} `json:"toClaimRewards"`
// total exp
// Format: int64
TotalExp int64 `json:"totalExp,omitempty"`
// total paid-for exp
// Format: int64
TotalPaidForExp int64 `json:"totalPaidForExp,omitempty"`
// total sweat exp
// Format: int64
TotalSweatExp int64 `json:"totalSweatExp,omitempty"`
// updated at
// Required: true
// Format: date-time
UpdatedAt strfmt.DateTime `json:"updatedAt"`
// user id
// Required: true
UserID *string `json:"userId"`
}
ClaimableUserSeasonInfo Claimable user season info
swagger:model Claimable user season info.
func (*ClaimableUserSeasonInfo) MarshalBinary ¶
func (m *ClaimableUserSeasonInfo) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*ClaimableUserSeasonInfo) UnmarshalBinary ¶
func (m *ClaimableUserSeasonInfo) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type ErrorEntity ¶
type ErrorEntity struct {
// internal server error stack trace in configured environment
DevStackTrace string `json:"devStackTrace,omitempty"`
// numeric error code
// Required: true
// Format: int32
ErrorCode *int32 `json:"errorCode"`
// error message
// Required: true
ErrorMessage *string `json:"errorMessage"`
// message variables
MessageVariables map[string]string `json:"messageVariables,omitempty"`
// requiredpermission
RequiredPermission *Permission `json:"requiredPermission,omitempty"`
}
ErrorEntity Error entity
swagger:model Error entity.
func (*ErrorEntity) MarshalBinary ¶
func (m *ErrorEntity) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*ErrorEntity) UnmarshalBinary ¶
func (m *ErrorEntity) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type ExcessStrategy ¶
type ExcessStrategy struct {
// virtual currency for grant, required while method is CURRENCY
Currency string `json:"currency,omitempty"`
// method while excess the final tier exp
// Enum: ['CURRENCY', 'NONE']
// Required: true
Method *string `json:"method"`
// percent per exp, required while method is CURRENCY
// Format: int32
PercentPerExp int32 `json:"percentPerExp,omitempty"`
}
ExcessStrategy Excess strategy
swagger:model Excess strategy.
func (*ExcessStrategy) MarshalBinary ¶
func (m *ExcessStrategy) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*ExcessStrategy) UnmarshalBinary ¶
func (m *ExcessStrategy) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type ExpGrantHistoryInfo ¶ added in v0.21.0
type ExpGrantHistoryInfo struct {
// acquired at
// Required: true
// Format: date-time
CreatedAt strfmt.DateTime `json:"createdAt"`
// grant exp
// Required: true
// Format: int64
GrantExp *int64 `json:"grantExp"`
// id
// Required: true
ID *string `json:"id"`
// namespace
// Required: true
Namespace *string `json:"namespace"`
// season id
// Required: true
SeasonID *string `json:"seasonId"`
// id
// Enum: ['PAID_FOR', 'SWEAT']
Source string `json:"source,omitempty"`
// id
Tags []string `json:"tags,omitempty"`
// user id
// Required: true
UserID *string `json:"userId"`
}
ExpGrantHistoryInfo Exp grant history info
swagger:model Exp grant history info.
func (*ExpGrantHistoryInfo) MarshalBinary ¶ added in v0.21.0
func (m *ExpGrantHistoryInfo) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*ExpGrantHistoryInfo) UnmarshalBinary ¶ added in v0.21.0
func (m *ExpGrantHistoryInfo) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type ExpGrantHistoryPagingSlicedResult ¶ added in v0.21.0
type ExpGrantHistoryPagingSlicedResult struct {
// data
// Required: true
Data []*ExpGrantHistoryInfo `json:"data"`
// paging
Paging *Paging `json:"paging,omitempty"`
// total
// Format: int64
Total int64 `json:"total,omitempty"`
}
ExpGrantHistoryPagingSlicedResult Exp grant history paging sliced result
swagger:model Exp grant history paging sliced result.
func (*ExpGrantHistoryPagingSlicedResult) MarshalBinary ¶ added in v0.21.0
func (m *ExpGrantHistoryPagingSlicedResult) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*ExpGrantHistoryPagingSlicedResult) UnmarshalBinary ¶ added in v0.21.0
func (m *ExpGrantHistoryPagingSlicedResult) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type FieldValidationError ¶
type FieldValidationError struct {
// errorcode
ErrorCode string `json:"errorCode,omitempty"`
// errorfield
ErrorField string `json:"errorField,omitempty"`
// errormessage
ErrorMessage string `json:"errorMessage,omitempty"`
// errorvalue
ErrorValue string `json:"errorValue,omitempty"`
// messagevariables
MessageVariables map[string]string `json:"messageVariables,omitempty"`
}
FieldValidationError Field validation error
swagger:model Field validation error.
func (*FieldValidationError) MarshalBinary ¶
func (m *FieldValidationError) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*FieldValidationError) UnmarshalBinary ¶
func (m *FieldValidationError) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type FullSeasonInfo ¶ added in v0.26.0
type FullSeasonInfo struct {
// id
// Required: true
ID *string `json:"id"`
// images
Images []*Image `json:"images,omitempty"`
// localization, {language: localization} map
// Required: true
Localizations map[string]Localization `json:"localizations"`
// name, max length is 127
// Required: true
Name *string `json:"name"`
// namespace
// Required: true
Namespace *string `json:"namespace"`
// passes info
// Required: true
Passes []*PassInfo `json:"passes"`
// rewards info
// Required: true
Rewards map[string]RewardInfo `json:"rewards"`
// tiers info
// Required: true
Tiers []*Tier `json:"tiers"`
}
FullSeasonInfo Full season info
swagger:model Full season info.
func (*FullSeasonInfo) MarshalBinary ¶ added in v0.26.0
func (m *FullSeasonInfo) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*FullSeasonInfo) UnmarshalBinary ¶ added in v0.26.0
func (m *FullSeasonInfo) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type Image ¶
type Image struct {
// image for
As string `json:"as,omitempty"`
// image caption
Caption string `json:"caption,omitempty"`
// height
// Required: true
// Format: int32
Height *int32 `json:"height"`
// imageUrl
// Required: true
ImageURL *string `json:"imageUrl"`
// smallImageUrl
SmallImageURL string `json:"smallImageUrl,omitempty"`
// width
// Required: true
// Format: int32
Width *int32 `json:"width"`
}
Image Image
swagger:model Image.
func (*Image) MarshalBinary ¶
MarshalBinary interface implementation
func (*Image) UnmarshalBinary ¶
UnmarshalBinary interface implementation
type ItemReference ¶ added in v0.78.0
type ItemReference struct {
// module
Module string `json:"module,omitempty"`
// references
References []map[string]interface{} `json:"references,omitempty"`
}
ItemReference Item reference
swagger:model Item reference.
func (*ItemReference) MarshalBinary ¶ added in v0.78.0
func (m *ItemReference) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*ItemReference) UnmarshalBinary ¶ added in v0.78.0
func (m *ItemReference) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type ItemReferenceInfo ¶ added in v0.78.0
type ItemReferenceInfo struct {
// item references
References []*ItemReference `json:"references,omitempty"`
}
ItemReferenceInfo Item reference info
swagger:model Item reference info.
func (*ItemReferenceInfo) MarshalBinary ¶ added in v0.78.0
func (m *ItemReferenceInfo) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*ItemReferenceInfo) UnmarshalBinary ¶ added in v0.78.0
func (m *ItemReferenceInfo) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type ListSeasonInfo ¶
type ListSeasonInfo struct {
// created at
// Required: true
// Format: date-time
CreatedAt strfmt.DateTime `json:"createdAt"`
// default language, BCP 47 language tag
// Required: true
DefaultLanguage *string `json:"defaultLanguage"`
// end date time
// Required: true
// Format: date-time
End strfmt.DateTime `json:"end"`
// id
// Required: true
ID *string `json:"id"`
// name, max length is 127
// Required: true
Name *string `json:"name"`
// namespace
// Required: true
Namespace *string `json:"namespace"`
// pass codes
// Unique: true
PassCodes []string `json:"passCodes"`
// publishedAt
// Format: date-time
PublishedAt *strfmt.DateTime `json:"publishedAt,omitempty"`
// start date time
// Required: true
// Format: date-time
Start strfmt.DateTime `json:"start"`
// status
// Enum: ['DRAFT', 'PUBLISHED', 'RETIRED']
// Required: true
Status *string `json:"status"`
// tier item id
// Required: true
TierItemID *string `json:"tierItemId"`
// tier item name
// Required: true
TierItemName *string `json:"tierItemName"`
// updated at
// Required: true
// Format: date-time
UpdatedAt strfmt.DateTime `json:"updatedAt"`
}
ListSeasonInfo List season info
swagger:model List season info.
func (*ListSeasonInfo) MarshalBinary ¶
func (m *ListSeasonInfo) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*ListSeasonInfo) UnmarshalBinary ¶
func (m *ListSeasonInfo) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type ListSeasonInfoPagingSlicedResult ¶
type ListSeasonInfoPagingSlicedResult struct {
// data
// Required: true
Data []*ListSeasonInfo `json:"data"`
// paging
Paging *Paging `json:"paging,omitempty"`
}
ListSeasonInfoPagingSlicedResult List season info paging sliced result
swagger:model List season info paging sliced result.
func (*ListSeasonInfoPagingSlicedResult) MarshalBinary ¶
func (m *ListSeasonInfoPagingSlicedResult) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*ListSeasonInfoPagingSlicedResult) UnmarshalBinary ¶
func (m *ListSeasonInfoPagingSlicedResult) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type ListUserSeasonInfo ¶
type ListUserSeasonInfo struct {
// whether cleared all tiers
// Required: true
Cleared *bool `json:"cleared"`
// current tier index, zero based
// Required: true
// Format: int32
CurrentTierIndex *int32 `json:"currentTierIndex"`
// enroll date time
// Required: true
// Format: date-time
EnrolledAt strfmt.DateTime `json:"enrolledAt"`
// id
// Required: true
ID *string `json:"id"`
// last tier index, zero based
// Required: true
// Format: int32
LastTierIndex *int32 `json:"lastTierIndex"`
// namespace
// Required: true
Namespace *string `json:"namespace"`
// season summary
Season *SeasonSummary `json:"season,omitempty"`
// season id
// Required: true
SeasonID *string `json:"seasonId"`
// user id
// Required: true
UserID *string `json:"userId"`
}
ListUserSeasonInfo List user season info
swagger:model List user season info.
func (*ListUserSeasonInfo) MarshalBinary ¶
func (m *ListUserSeasonInfo) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*ListUserSeasonInfo) UnmarshalBinary ¶
func (m *ListUserSeasonInfo) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type ListUserSeasonInfoPagingSlicedResult ¶
type ListUserSeasonInfoPagingSlicedResult struct {
// data
// Required: true
Data []*ListUserSeasonInfo `json:"data"`
// paging
Paging *Paging `json:"paging,omitempty"`
// total
// Format: int64
Total int64 `json:"total,omitempty"`
}
ListUserSeasonInfoPagingSlicedResult List user season info paging sliced result
swagger:model List user season info paging sliced result.
func (*ListUserSeasonInfoPagingSlicedResult) MarshalBinary ¶
func (m *ListUserSeasonInfoPagingSlicedResult) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*ListUserSeasonInfoPagingSlicedResult) UnmarshalBinary ¶
func (m *ListUserSeasonInfoPagingSlicedResult) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type Localization ¶
type Localization struct {
// description info
Description string `json:"description,omitempty"`
// title info
Title string `json:"title,omitempty"`
}
Localization Localization
swagger:model Localization.
func (*Localization) MarshalBinary ¶
func (m *Localization) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*Localization) UnmarshalBinary ¶
func (m *Localization) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type LocalizedPassInfo ¶
type LocalizedPassInfo struct {
// autoEnroll
// Required: true
AutoEnroll *bool `json:"autoEnroll"`
// code
// Required: true
Code *string `json:"code"`
// created at
// Required: true
// Format: date-time
CreatedAt strfmt.DateTime `json:"createdAt"`
// description info
Description string `json:"description,omitempty"`
// displayOrder
// Required: true
DisplayOrder *string `json:"displayOrder"`
// images
Images []*Image `json:"images,omitempty"`
// current language
// Required: true
Language *string `json:"language"`
// namespace
// Required: true
Namespace *string `json:"namespace"`
// pass item id
// Required: true
PassItemID *string `json:"passItemId"`
// season id
// Required: true
SeasonID *string `json:"seasonId"`
// title info
Title string `json:"title,omitempty"`
// updated at
// Required: true
// Format: date-time
UpdatedAt strfmt.DateTime `json:"updatedAt"`
}
LocalizedPassInfo Localized pass info
swagger:model Localized pass info.
func (*LocalizedPassInfo) MarshalBinary ¶
func (m *LocalizedPassInfo) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*LocalizedPassInfo) UnmarshalBinary ¶
func (m *LocalizedPassInfo) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type LocalizedSeasonInfo ¶
type LocalizedSeasonInfo struct {
// whether auto claim rewards
// Required: true
AutoClaim *bool `json:"autoClaim"`
// created at
// Required: true
// Format: date-time
CreatedAt strfmt.DateTime `json:"createdAt"`
// description info
Description string `json:"description,omitempty"`
// end date time
// Required: true
// Format: date-time
End strfmt.DateTime `json:"end"`
// id
// Required: true
ID *string `json:"id"`
// images
Images []*Image `json:"images,omitempty"`
// current language
// Required: true
Language *string `json:"language"`
// name, max length is 127
// Required: true
Name *string `json:"name"`
// namespace
// Required: true
Namespace *string `json:"namespace"`
// pass codes
// Unique: true
PassCodes []string `json:"passCodes"`
// passes info
// Required: true
Passes []*LocalizedPassInfo `json:"passes"`
// publishedAt
// Format: date-time
PublishedAt *strfmt.DateTime `json:"publishedAt,omitempty"`
// rewards info
// Required: true
Rewards map[string]RewardInfo `json:"rewards"`
// start date time
// Required: true
// Format: date-time
Start strfmt.DateTime `json:"start"`
// status
// Enum: ['DRAFT', 'PUBLISHED', 'RETIRED']
// Required: true
Status *string `json:"status"`
// tier item id
// Required: true
TierItemID *string `json:"tierItemId"`
// tiers info
// Required: true
Tiers []*Tier `json:"tiers"`
// title info
Title string `json:"title,omitempty"`
// updated at
// Required: true
// Format: date-time
UpdatedAt strfmt.DateTime `json:"updatedAt"`
}
LocalizedSeasonInfo Localized season info
swagger:model Localized season info.
func (*LocalizedSeasonInfo) MarshalBinary ¶
func (m *LocalizedSeasonInfo) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*LocalizedSeasonInfo) UnmarshalBinary ¶
func (m *LocalizedSeasonInfo) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type Ownership ¶
type Ownership struct {
// ownership
// Required: true
Owned *bool `json:"owned"`
}
Ownership Ownership
swagger:model Ownership.
func (*Ownership) MarshalBinary ¶
MarshalBinary interface implementation
func (*Ownership) UnmarshalBinary ¶
UnmarshalBinary interface implementation
type Paging ¶
type Paging struct {
// next
Next string `json:"next,omitempty"`
// previous
Previous string `json:"previous,omitempty"`
}
Paging Paging
swagger:model Paging.
func (*Paging) MarshalBinary ¶
MarshalBinary interface implementation
func (*Paging) UnmarshalBinary ¶
UnmarshalBinary interface implementation
type PassCreate ¶
type PassCreate struct {
// autoEnroll for free pass, default false
AutoEnroll bool `json:"autoEnroll"`
// code, allowed characters from a-z0-9_:- and start/end in alphanumeric, max length is 255
// Required: true
Code *string `json:"code"`
// displayOrder for frontend to arrange the pass
// Required: true
// Format: int32
DisplayOrder *int32 `json:"displayOrder"`
// images
Images []*Image `json:"images,omitempty"`
// localization, {language: localization} map
// Required: true
Localizations map[string]Localization `json:"localizations"`
// pass item id
// Required: true
PassItemID *string `json:"passItemId"`
}
PassCreate Pass create
swagger:model Pass create.
func (*PassCreate) MarshalBinary ¶
func (m *PassCreate) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*PassCreate) UnmarshalBinary ¶
func (m *PassCreate) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type PassInfo ¶
type PassInfo struct {
// autoEnroll
// Required: true
AutoEnroll *bool `json:"autoEnroll"`
// code
// Required: true
Code *string `json:"code"`
// created at
// Required: true
// Format: date-time
CreatedAt strfmt.DateTime `json:"createdAt"`
// displayOrder
// Required: true
DisplayOrder *string `json:"displayOrder"`
// images
Images []*Image `json:"images,omitempty"`
// localization, {language: localization} map
// Required: true
Localizations map[string]Localization `json:"localizations"`
// namespace
// Required: true
Namespace *string `json:"namespace"`
// pass item id
// Required: true
PassItemID *string `json:"passItemId"`
// pass item name
// Required: true
PassItemName *string `json:"passItemName"`
// season id
// Required: true
SeasonID *string `json:"seasonId"`
// updated at
// Required: true
// Format: date-time
UpdatedAt strfmt.DateTime `json:"updatedAt"`
}
PassInfo Pass info
swagger:model Pass info.
func (*PassInfo) MarshalBinary ¶
MarshalBinary interface implementation
func (*PassInfo) UnmarshalBinary ¶
UnmarshalBinary interface implementation
type PassUpdate ¶
type PassUpdate struct {
// autoEnroll for free pass
AutoEnroll bool `json:"autoEnroll"`
// displayOrder for frontend to arrange the pass
// Format: int32
DisplayOrder int32 `json:"displayOrder,omitempty"`
// images
Images []*Image `json:"images,omitempty"`
// localization, {language: localization} map
Localizations map[string]Localization `json:"localizations,omitempty"`
// pass item id
PassItemID string `json:"passItemId,omitempty"`
}
PassUpdate Pass update
swagger:model Pass update.
func (*PassUpdate) MarshalBinary ¶
func (m *PassUpdate) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*PassUpdate) UnmarshalBinary ¶
func (m *PassUpdate) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type Permission ¶ added in v0.72.0
type Permission struct {
// action
// Format: int32
Action int32 `json:"action,omitempty"`
// resource
Resource string `json:"resource,omitempty"`
}
Permission Permission
swagger:model Permission.
func (*Permission) MarshalBinary ¶ added in v0.72.0
func (m *Permission) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*Permission) UnmarshalBinary ¶ added in v0.72.0
func (m *Permission) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type ReasonTagsResult ¶ added in v0.21.0
type ReasonTagsResult struct {
// tags
// Required: true
Tags []string `json:"tags"`
}
ReasonTagsResult Reason tags result
swagger:model Reason tags result.
func (*ReasonTagsResult) MarshalBinary ¶ added in v0.21.0
func (m *ReasonTagsResult) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*ReasonTagsResult) UnmarshalBinary ¶ added in v0.21.0
func (m *ReasonTagsResult) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type RewardCreate ¶
type RewardCreate struct {
// code, allowed characters from a-z0-9_:- and start/end in alphanumeric, max length is 255
// Required: true
Code *string `json:"code"`
// currency, required when reward type is CURRENCY
Currency *RewardCurrency `json:"currency,omitempty"`
// image, thumbnail for reward
Image *Image `json:"image,omitempty"`
// itemId, required when reward type is ITEM, the item type should be one of: INGAMEITEM,COINS,BUNDLE
ItemID string `json:"itemId,omitempty"`
// Item quantity or Currency amount, default 1
// Format: int32
Quantity int32 `json:"quantity,omitempty"`
// type, at current only support ITEM
// Enum: ['CURRENCY', 'ITEM']
// Required: true
Type *string `json:"type"`
}
RewardCreate Reward create
swagger:model Reward create.
func (*RewardCreate) MarshalBinary ¶
func (m *RewardCreate) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*RewardCreate) UnmarshalBinary ¶
func (m *RewardCreate) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type RewardCurrency ¶
type RewardCurrency struct {
// currency code, alphabet uppercase
// Required: true
CurrencyCode *string `json:"currencyCode"`
// namespace, allowed values: game namespace or publisher namespace
// Required: true
Namespace *string `json:"namespace"`
}
RewardCurrency Reward currency
swagger:model Reward currency.
func (*RewardCurrency) MarshalBinary ¶
func (m *RewardCurrency) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*RewardCurrency) UnmarshalBinary ¶
func (m *RewardCurrency) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type RewardInfo ¶
type RewardInfo struct {
// code
// Required: true
Code *string `json:"code"`
// currency, required when reward type is CURRENCY
Currency *RewardCurrency `json:"currency,omitempty"`
// image, thumbnail for reward
Image *Image `json:"image,omitempty"`
// itemId, required when reward type is ITEM
ItemID string `json:"itemId,omitempty"`
// itemName, required when reward type is ITEM
ItemName string `json:"itemName,omitempty"`
// itemSku, required when reward type is ITEM
ItemSku string `json:"itemSku,omitempty"`
// itemType, required when reward type is ITEM
// Enum: ['APP', 'BUNDLE', 'CODE', 'COINS', 'EXTENSION', 'INGAMEITEM', 'LOOTBOX', 'MEDIA', 'OPTIONBOX', 'SEASON', 'SUBSCRIPTION']
ItemType string `json:"itemType,omitempty"`
// namespace
// Required: true
Namespace *string `json:"namespace"`
// Item quantity or Currency amount, default 1
// Format: int32
Quantity int32 `json:"quantity,omitempty"`
// seasonId
// Required: true
SeasonID *string `json:"seasonId"`
// type
// Enum: ['CURRENCY', 'ITEM']
// Required: true
Type *string `json:"type"`
}
RewardInfo Reward info
swagger:model Reward info.
func (*RewardInfo) MarshalBinary ¶
func (m *RewardInfo) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*RewardInfo) UnmarshalBinary ¶
func (m *RewardInfo) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type RewardUpdate ¶
type RewardUpdate struct {
// currency, required when reward type is CURRENCY
Currency *RewardCurrency `json:"currency,omitempty"`
// image, thumbnail for reward
Image *Image `json:"image,omitempty"`
// itemId, required when reward type is ITEM, the item type should be one of: INGAMEITEM,COINS,BUNDLE
ItemID string `json:"itemId,omitempty"`
// nullFields
// Unique: true
NullFields []string `json:"nullFields"`
// Item quantity or Currency amount, default 1
// Format: int32
Quantity int32 `json:"quantity,omitempty"`
// type, at current only support ITEM
// Enum: ['CURRENCY', 'ITEM']
Type string `json:"type,omitempty"`
}
RewardUpdate Reward update
swagger:model Reward update.
func (*RewardUpdate) MarshalBinary ¶
func (m *RewardUpdate) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*RewardUpdate) UnmarshalBinary ¶
func (m *RewardUpdate) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type SeasonCloneRequest ¶
type SeasonCloneRequest struct {
// end date time
// Required: true
// Format: date-time
End strfmt.DateTime `json:"end"`
// name, max length is 127
// Required: true
Name *string `json:"name"`
// start date time
// Required: true
// Format: date-time
Start strfmt.DateTime `json:"start"`
}
SeasonCloneRequest Season clone request
swagger:model Season clone request.
func (*SeasonCloneRequest) MarshalBinary ¶
func (m *SeasonCloneRequest) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*SeasonCloneRequest) UnmarshalBinary ¶
func (m *SeasonCloneRequest) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type SeasonCreate ¶
type SeasonCreate struct {
// whether auto claim rewards, default true
AutoClaim bool `json:"autoClaim"`
// default language, BCP 47 language tag, default is en
DefaultLanguage string `json:"defaultLanguage,omitempty"`
// default exp required for a tier
// Required: true
// Format: int32
DefaultRequiredExp *int32 `json:"defaultRequiredExp"`
// draft store id
// Required: true
DraftStoreID *string `json:"draftStoreId"`
// end date time
// Required: true
// Format: date-time
End strfmt.DateTime `json:"end"`
// strategy while exceed final tier exp, default NONE
ExcessStrategy *ExcessStrategy `json:"excessStrategy,omitempty"`
// images
Images []*Image `json:"images,omitempty"`
// localization, {language: localization} map
// Required: true
Localizations map[string]Localization `json:"localizations"`
// name, max length is 127
// Required: true
Name *string `json:"name"`
// start date time
// Required: true
// Format: date-time
Start strfmt.DateTime `json:"start"`
// tier item id
// Required: true
TierItemID *string `json:"tierItemId"`
}
SeasonCreate Season create
swagger:model Season create.
func (*SeasonCreate) MarshalBinary ¶
func (m *SeasonCreate) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*SeasonCreate) UnmarshalBinary ¶
func (m *SeasonCreate) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type SeasonInfo ¶
type SeasonInfo struct {
// whether auto claim rewards
// Required: true
AutoClaim *bool `json:"autoClaim"`
// created at
// Required: true
// Format: date-time
CreatedAt strfmt.DateTime `json:"createdAt"`
// default language, BCP 47 language tag
// Required: true
DefaultLanguage *string `json:"defaultLanguage"`
// default required exp for a tier
// Required: true
// Format: int32
DefaultRequiredExp *int32 `json:"defaultRequiredExp"`
// draft store id
// Required: true
DraftStoreID *string `json:"draftStoreId"`
// end date time
// Required: true
// Format: date-time
End strfmt.DateTime `json:"end"`
// strategy while exceed final tier exp
// Required: true
ExcessStrategy *ExcessStrategy `json:"excessStrategy"`
// id
// Required: true
ID *string `json:"id"`
// images
Images []*Image `json:"images,omitempty"`
// localization, {language: localization} map
// Required: true
Localizations map[string]Localization `json:"localizations"`
// name, max length is 127
// Required: true
Name *string `json:"name"`
// namespace
// Required: true
Namespace *string `json:"namespace"`
// pass codes
// Unique: true
PassCodes []string `json:"passCodes"`
// publishedAt
// Format: date-time
PublishedAt *strfmt.DateTime `json:"publishedAt,omitempty"`
// start date time
// Required: true
// Format: date-time
Start strfmt.DateTime `json:"start"`
// status
// Enum: ['DRAFT', 'PUBLISHED', 'RETIRED']
// Required: true
Status *string `json:"status"`
// tier item id
// Required: true
TierItemID *string `json:"tierItemId"`
// tier item name
// Required: true
TierItemName *string `json:"tierItemName"`
// updated at
// Required: true
// Format: date-time
UpdatedAt strfmt.DateTime `json:"updatedAt"`
}
SeasonInfo Season info
swagger:model Season info.
func (*SeasonInfo) MarshalBinary ¶
func (m *SeasonInfo) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*SeasonInfo) UnmarshalBinary ¶
func (m *SeasonInfo) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type SeasonSummary ¶
type SeasonSummary struct {
// end date time
// Required: true
// Format: date-time
End strfmt.DateTime `json:"end"`
// id
// Required: true
ID *string `json:"id"`
// name, max length is 127
// Required: true
Name *string `json:"name"`
// namespace
// Required: true
Namespace *string `json:"namespace"`
// season pass codes
// Unique: true
PassCodes []string `json:"passCodes"`
// previous season, only present in some situation
Previous *SeasonSummary `json:"previous,omitempty"`
// publishedAt
// Format: date-time
PublishedAt *strfmt.DateTime `json:"publishedAt,omitempty"`
// start date time
// Required: true
// Format: date-time
Start strfmt.DateTime `json:"start"`
// status
// Enum: ['DRAFT', 'PUBLISHED', 'RETIRED']
// Required: true
Status *string `json:"status"`
}
SeasonSummary Season summary
swagger:model Season summary.
func (*SeasonSummary) MarshalBinary ¶
func (m *SeasonSummary) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*SeasonSummary) UnmarshalBinary ¶
func (m *SeasonSummary) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type SeasonUpdate ¶
type SeasonUpdate struct {
// whether auto claim rewards
AutoClaim bool `json:"autoClaim"`
// default language, BCP 47 language tag
DefaultLanguage string `json:"defaultLanguage,omitempty"`
// default exp required for a tier
// Format: int32
DefaultRequiredExp int32 `json:"defaultRequiredExp,omitempty"`
// draft store id
DraftStoreID string `json:"draftStoreId,omitempty"`
// end date time
// Format: date-time
End *strfmt.DateTime `json:"end,omitempty"`
// strategy while exceed final tier exp
ExcessStrategy *ExcessStrategy `json:"excessStrategy,omitempty"`
// images
Images []*Image `json:"images,omitempty"`
// localization, {language: localization} map
Localizations map[string]Localization `json:"localizations,omitempty"`
// name, max length is 127
Name string `json:"name,omitempty"`
// start date time
// Format: date-time
Start *strfmt.DateTime `json:"start,omitempty"`
// tier item id
TierItemID string `json:"tierItemId,omitempty"`
}
SeasonUpdate Season update
swagger:model Season update.
func (*SeasonUpdate) MarshalBinary ¶
func (m *SeasonUpdate) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*SeasonUpdate) UnmarshalBinary ¶
func (m *SeasonUpdate) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type Tier ¶
type Tier struct {
// tier id, auto generated.
ID string `json:"id,omitempty"`
// required exp for tier, it will automatically use season defaultRequiredExp if not set
// Format: int32
RequiredExp int32 `json:"requiredExp,omitempty"`
// rewards map, passCode as key, rewardCode list as value
Rewards map[string][]string `json:"rewards,omitempty"`
}
Tier Tier
swagger:model Tier.
func (*Tier) MarshalBinary ¶
MarshalBinary interface implementation
func (*Tier) UnmarshalBinary ¶
UnmarshalBinary interface implementation
type TierCreate ¶
type TierCreate struct {
// zero based tier index to be inserted at, -1 means appending to the end, default -1
// Format: int32
Index int32 `json:"index,omitempty"`
// create tier quantity, default 1
// Format: int32
Quantity int32 `json:"quantity,omitempty"`
// tier content, default null tier
Tier *TierInput `json:"tier,omitempty"`
}
TierCreate Tier create
swagger:model Tier create.
func (*TierCreate) MarshalBinary ¶
func (m *TierCreate) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*TierCreate) UnmarshalBinary ¶
func (m *TierCreate) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type TierInput ¶
type TierInput struct {
// required exp for tier, it will automatically use season defaultRequiredExp if not set
// Format: int32
RequiredExp int32 `json:"requiredExp,omitempty"`
// rewards map, passCode as key, rewardCode list as value
Rewards map[string][]string `json:"rewards,omitempty"`
}
TierInput Tier input
swagger:model Tier input.
func (*TierInput) MarshalBinary ¶
MarshalBinary interface implementation
func (*TierInput) UnmarshalBinary ¶
UnmarshalBinary interface implementation
type TierPagingSlicedResult ¶
type TierPagingSlicedResult struct {
// data
// Required: true
Data []*Tier `json:"data"`
// paging
Paging *Paging `json:"paging,omitempty"`
// total
// Format: int64
Total int64 `json:"total,omitempty"`
}
TierPagingSlicedResult Tier paging sliced result
swagger:model Tier paging sliced result.
func (*TierPagingSlicedResult) MarshalBinary ¶
func (m *TierPagingSlicedResult) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*TierPagingSlicedResult) UnmarshalBinary ¶
func (m *TierPagingSlicedResult) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type TierReorder ¶ added in v0.12.0
type TierReorder struct {
// new index tier should be moved to, zero based, -1 means appending to the end
// Format: int32
NewIndex int32 `json:"newIndex,omitempty"`
}
TierReorder Tier reorder
swagger:model Tier reorder.
func (*TierReorder) MarshalBinary ¶ added in v0.12.0
func (m *TierReorder) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*TierReorder) UnmarshalBinary ¶ added in v0.12.0
func (m *TierReorder) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type UserExpGrant ¶
type UserExpGrant struct {
// exp to grant
// Format: int32
Exp int32 `json:"exp,omitempty"`
// source
// Enum: ['PAID_FOR', 'SWEAT']
Source string `json:"source,omitempty"`
// tags
Tags []string `json:"tags,omitempty"`
}
UserExpGrant User exp grant
swagger:model User exp grant.
func (*UserExpGrant) MarshalBinary ¶
func (m *UserExpGrant) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*UserExpGrant) UnmarshalBinary ¶
func (m *UserExpGrant) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type UserPassGrant ¶
type UserPassGrant struct {
// pass code, required if passItemId null
PassCode string `json:"passCode,omitempty"`
// pass item id, required if passCode null and ignored if passCode present
PassItemID string `json:"passItemId,omitempty"`
}
UserPassGrant User pass grant
swagger:model User pass grant.
func (*UserPassGrant) MarshalBinary ¶
func (m *UserPassGrant) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*UserPassGrant) UnmarshalBinary ¶
func (m *UserPassGrant) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type UserPurchasable ¶
type UserPurchasable struct {
// pass item id
PassItemID string `json:"passItemId,omitempty"`
// tier item count, default 1
// Format: int32
TierItemCount int32 `json:"tierItemCount,omitempty"`
// tier item id
TierItemID string `json:"tierItemId,omitempty"`
}
UserPurchasable User purchasable
swagger:model User purchasable.
func (*UserPurchasable) MarshalBinary ¶
func (m *UserPurchasable) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*UserPurchasable) UnmarshalBinary ¶
func (m *UserPurchasable) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type UserRewardClaim ¶
type UserRewardClaim struct {
// pass code
// Required: true
PassCode *string `json:"passCode"`
// reward code
// Required: true
RewardCode *string `json:"rewardCode"`
// tier index
// Required: true
// Format: int32
TierIndex *int32 `json:"tierIndex"`
}
UserRewardClaim User reward claim
swagger:model User reward claim.
func (*UserRewardClaim) MarshalBinary ¶
func (m *UserRewardClaim) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*UserRewardClaim) UnmarshalBinary ¶
func (m *UserRewardClaim) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type UserSeasonSummary ¶
type UserSeasonSummary struct {
// whether cleared all tiers
Cleared bool `json:"cleared"`
// created at
// Format: date-time
CreatedAt *strfmt.DateTime `json:"createdAt,omitempty"`
// gained exp for current tier
// Format: int32
CurrentExp int32 `json:"currentExp,omitempty"`
// current tier index, zero based
// Format: int32
CurrentTierIndex int32 `json:"currentTierIndex,omitempty"`
// enroll date time
// Format: date-time
EnrolledAt *strfmt.DateTime `json:"enrolledAt,omitempty"`
// enrolled passes
// Unique: true
EnrolledPasses []string `json:"enrolledPasses"`
// id
ID string `json:"id,omitempty"`
// last tier index, zero based
// Format: int32
LastTierIndex int32 `json:"lastTierIndex,omitempty"`
// namespace
// Required: true
Namespace *string `json:"namespace"`
// required exp for current tier
// Format: int32
RequiredExp int32 `json:"requiredExp,omitempty"`
// season id
SeasonID string `json:"seasonId,omitempty"`
// updated at
// Format: date-time
UpdatedAt *strfmt.DateTime `json:"updatedAt,omitempty"`
// user id
// Required: true
UserID *string `json:"userId"`
}
UserSeasonSummary User season summary
swagger:model User season summary.
func (*UserSeasonSummary) MarshalBinary ¶
func (m *UserSeasonSummary) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*UserSeasonSummary) UnmarshalBinary ¶
func (m *UserSeasonSummary) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type UserTierGrant ¶
type UserTierGrant struct {
// count to grant
// Format: int32
Count int32 `json:"count,omitempty"`
// source
// Enum: ['PAID_FOR', 'SWEAT']
Source string `json:"source,omitempty"`
// tags
Tags []string `json:"tags,omitempty"`
}
UserTierGrant User tier grant
swagger:model User tier grant.
func (*UserTierGrant) MarshalBinary ¶
func (m *UserTierGrant) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*UserTierGrant) UnmarshalBinary ¶
func (m *UserTierGrant) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type ValidationErrorEntity ¶
type ValidationErrorEntity struct {
// numeric error code
// Required: true
// Format: int32
ErrorCode *int32 `json:"errorCode"`
// error message
// Required: true
ErrorMessage *string `json:"errorMessage"`
// errors
Errors []*FieldValidationError `json:"errors,omitempty"`
}
ValidationErrorEntity Validation error entity
swagger:model Validation error entity.
func (*ValidationErrorEntity) MarshalBinary ¶
func (m *ValidationErrorEntity) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*ValidationErrorEntity) UnmarshalBinary ¶
func (m *ValidationErrorEntity) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
Source Files
¶
- bulk_user_progression_request.go
- claimable_rewards.go
- claimable_user_season_info.go
- error_entity.go
- excess_strategy.go
- exp_grant_history_info.go
- exp_grant_history_paging_sliced_result.go
- field_validation_error.go
- full_season_info.go
- image.go
- item_reference.go
- item_reference_info.go
- list_season_info.go
- list_season_info_paging_sliced_result.go
- list_user_season_info.go
- list_user_season_info_paging_sliced_result.go
- localization.go
- localized_pass_info.go
- localized_season_info.go
- ownership.go
- paging.go
- pass_create.go
- pass_info.go
- pass_update.go
- permission.go
- reason_tags_result.go
- reward_create.go
- reward_currency.go
- reward_info.go
- reward_update.go
- season_clone_request.go
- season_create.go
- season_info.go
- season_summary.go
- season_update.go
- tier.go
- tier_create.go
- tier_input.go
- tier_paging_sliced_result.go
- tier_reorder.go
- user_exp_grant.go
- user_pass_grant.go
- user_purchasable.go
- user_reward_claim.go
- user_season_summary.go
- user_tier_grant.go
- validation_error_entity.go